@@ -1,18 +1,30 @@
- /*
- 				astrom.c
-
-*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+/*
+*				astrom.c
 *
-*	Part of:	SExtractor
+* High level astrometric computations.
 *
-*	Author:		E.BERTIN (IAP)
+*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 *
-*	Contents:	Astrometrical computations.
+*	This file part of:	SExtractor
 *
-*	Last modify:	19/05/2008
+*	Copyright:		(C) 1993-2010 Emmanuel Bertin -- IAP/CNRS/UPMC
 *
-*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-*/
+*	License:		GNU General Public License
+*
+*	SExtractor is free software: you can redistribute it and/or modify
+*	it under the terms of the GNU General Public License as published by
+*	the Free Software Foundation, either version 3 of the License, or
+*	(at your option) any later version.
+*	SExtractor is distributed in the hope that it will be useful,
+*	but WITHOUT ANY WARRANTY; without even the implied warranty of
+*	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+*	GNU General Public License for more details.
+*	You should have received a copy of the GNU General Public License
+*	along with SExtractor. If not, see <http://www.gnu.org/licenses/>.
+*
+*	Last modified:		11/10/2010
+*
+*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%*/
 
 #ifdef HAVE_CONFIG_H
 #include        "config.h"
@@ -46,15 +58,7 @@ void	initastrom(picstruct *field)
 /* Test if the WCS is in use */
   if (wcs->lng != wcs->lat)
     {
-    if (FLAG(obj2.theta2000) || FLAG(obj2.theta1950)
-	|| FLAG(obj2.poserr_theta2000) || FLAG(obj2.poserr_theta1950)
-	|| FLAG(obj2.win_theta2000) || FLAG(obj2.win_theta1950)
-	|| FLAG(obj2.winposerr_theta2000) || FLAG(obj2.winposerr_theta1950)
-	|| FLAG(obj2.prof_spheroid_theta2000)
-	|| FLAG(obj2.prof_spheroid_theta1950)
-	|| FLAG(obj2.prof_disk_theta2000) || FLAG(obj2.prof_disk_theta1950)
-//	|| FLAG(obj2.prof_arms_theta2000) || FLAG(obj2.prof_arms_theta1950)
-	|| FLAG(obj2.prof_bar_theta2000) || FLAG(obj2.prof_bar_theta1950))
+    if (FLAG(obj2.dtheta2000) || FLAG(obj2.dtheta1950))
       {
       if (fabs(wcs->equinox-2000.0)>0.003)
         precess(wcs->equinox, 0.0, 90.0, 2000.0, &wcs->ap2000, &wcs->dp2000);
@@ -79,22 +83,31 @@ void	initastrom(picstruct *field)
   }
 
 
-/**************************** computeastrom *********************************/
+/***************************** astrom_pos **********************************/
 /*
-Compute real WORLD coordinates and dimensions according to FITS info.
+Compute real FOCAL and WORLD coordinates according to FITS info.
 */
-void	computeastrom(picstruct *field, objstruct *obj)
+void	astrom_pos(picstruct *field, objstruct *obj)
 
   {
    wcsstruct	*wcs;
    double	rawpos[NAXIS], wcspos[NAXIS],
-		pixscale2, da,dd;
+		da,dd;
    int		lng,lat;
 
   wcs = field->wcs;
   lng = wcs->lng;
   lat = wcs->lat;
-  pixscale2 = 0.0;	/* To avoid gcc -Wall warnings */
+
+/* If working with WCS, compute FOCAL coordinates and local matrix */
+  if (FLAG(obj2.mxf))
+    {
+    rawpos[0] = obj2->posx;
+    rawpos[1] = obj2->posy;
+    raw_to_red(wcs, rawpos, wcspos);
+    obj2->mxf = wcspos[0];
+    obj2->myf = wcspos[1];
+    }
 
 /* If working with WCS, compute WORLD coordinates and local matrix */
   if (FLAG(obj2.mxw))
@@ -145,7 +158,43 @@ void	computeastrom(picstruct *field, objstruct *obj)
       }
     }
 
-/* Idem for peak-flux positions */
+/* Custom coordinate system for the MAMA machine */
+  if (FLAG(obj2.mamaposx))
+    {
+    rawpos[0] = obj2->posx - 0.5;
+    rawpos[1] = obj2->posy - 0.5;
+    raw_to_wcs(wcs, rawpos, wcspos);
+    obj2->mamaposx = wcspos[1]*(MAMA_CORFLEX+1.0);
+    obj2->mamaposy = wcspos[0]*(MAMA_CORFLEX+1.0);
+    }
+
+  return;
+  }
+
+
+/***************************** astrom_peakpos *******************************/
+/*
+Compute real FOCAL and WORLD peak coordinates according to FITS info.
+*/
+void	astrom_peakpos(picstruct *field, objstruct *obj)
+
+  {
+   wcsstruct	*wcs;
+   double	rawpos[NAXIS], wcspos[NAXIS];
+   int		lng,lat;
+
+  wcs = field->wcs;
+  lng = wcs->lng;
+  lat = wcs->lat;
+
+  if (FLAG(obj2.peakxf))
+    {
+    rawpos[0] = obj->peakx;
+    rawpos[1] = obj->peaky;
+    raw_to_red(wcs, rawpos, wcspos);
+    obj2->peakxf = wcspos[0];
+    obj2->peakyf = wcspos[1];
+    }
   if (FLAG(obj2.peakxw))
     {
     rawpos[0] = obj->peakx;
@@ -174,7 +223,33 @@ void	computeastrom(picstruct *field, objstruct *obj)
       }
     }
 
-/* Idem for Windowed positions */
+  return;
+  }
+
+
+/****************************** astrom_winpos *******************************/
+/*
+Compute real FOCAL and WORLD windowed coordinates according to FITS info.
+*/
+void	astrom_winpos(picstruct *field, objstruct *obj)
+
+  {
+   wcsstruct	*wcs;
+   double	rawpos[NAXIS], wcspos[NAXIS];
+   int		lng,lat;
+
+  wcs = field->wcs;
+  lng = wcs->lng;
+  lat = wcs->lat;
+
+  if (FLAG(obj2.winpos_xf))
+    {
+    rawpos[0] = obj2->winpos_x;
+    rawpos[1] = obj2->winpos_y;
+    raw_to_red(wcs, rawpos, wcspos);
+    obj2->winpos_xf = wcspos[0];
+    obj2->winpos_yf = wcspos[1];
+    }
   if (FLAG(obj2.winpos_xw))
     {
     rawpos[0] = obj2->winpos_x;
@@ -203,7 +278,88 @@ void	computeastrom(picstruct *field, objstruct *obj)
       }
     }
 
-/* Idem for Model-fitted positions */
+  return;
+  }
+
+
+/****************************** astrom_psfpos *******************************/
+/*
+Compute real FOCAL and WORLD PSF coordinates according to FITS info.
+*/
+void	astrom_psfpos(picstruct *field, objstruct *obj)
+
+  {
+   wcsstruct	*wcs;
+   double	rawpos[NAXIS], wcspos[NAXIS];
+   int		lng,lat;
+
+  wcs = field->wcs;
+  lng = wcs->lng;
+  lat = wcs->lat;
+
+  if (FLAG(obj2.xf_psf))
+    {
+    rawpos[0] = obj2->x_psf;
+    rawpos[1] = obj2->y_psf;
+    raw_to_red(wcs, rawpos, wcspos);
+    obj2->xf_psf = wcspos[0];
+    obj2->yf_psf = wcspos[1];
+    }
+  if (FLAG(obj2.xw_psf))
+    {
+    rawpos[0] = obj2->x_psf;
+    rawpos[1] = obj2->y_psf;
+    raw_to_wcs(wcs, rawpos, wcspos);
+    obj2->xw_psf = wcspos[0];
+    obj2->yw_psf = wcspos[1];
+    if (lng != lat)
+      {
+      obj2->alphas_psf = lng<lat? obj2->xw_psf : obj2->yw_psf;
+      obj2->deltas_psf = lng<lat? obj2->yw_psf : obj2->xw_psf;
+      if (FLAG(obj2.alpha2000_psf))
+        {
+        if (fabs(wcs->equinox-2000.0)>0.003)
+          precess(wcs->equinox, wcspos[0], wcspos[1],
+		2000.0, &obj2->alpha2000_psf, &obj2->delta2000_psf);
+        else
+          {
+          obj2->alpha2000_psf = lng<lat? obj2->xw_psf : obj2->yw_psf;
+          obj2->delta2000_psf = lng<lat? obj2->yw_psf : obj2->xw_psf;
+          }
+        if (FLAG(obj2.alpha1950_psf))
+          j2b(wcs->equinox, obj2->alpha2000_psf, obj2->delta2000_psf,
+		&obj2->alpha1950_psf, &obj2->delta1950_psf);
+        }
+      }
+    }
+
+  return;
+  }
+
+
+/****************************** astrom_profpos *******************************/
+/*
+Compute real FOCAL and WORLD profit coordinates according to FITS info.
+*/
+void	astrom_profpos(picstruct *field, objstruct *obj)
+
+  {
+   wcsstruct	*wcs;
+   double	rawpos[NAXIS], wcspos[NAXIS];
+   int		lng,lat;
+
+  wcs = field->wcs;
+  lng = wcs->lng;
+  lat = wcs->lat;
+
+  if (FLAG(obj2.xf_prof))
+    {
+    rawpos[0] = obj2->x_prof;
+    rawpos[1] = obj2->y_prof;
+    raw_to_red(wcs, rawpos, wcspos);
+    obj2->xf_prof = wcspos[0];
+    obj2->yf_prof = wcspos[1];
+    }
   if (FLAG(obj2.xw_prof))
     {
     rawpos[0] = obj2->x_prof;
@@ -232,58 +388,6 @@ void	computeastrom(picstruct *field, objstruct *obj)
       }
     }
 
-/* Custom coordinate system for the MAMA machine */
-  if (FLAG(obj2.mamaposx))
-    {
-    rawpos[0] = obj2->posx - 0.5;
-    rawpos[1] = obj2->posy - 0.5;
-    raw_to_wcs(wcs, rawpos, wcspos);
-    obj2->mamaposx = wcspos[1]*(MAMA_CORFLEX+1.0);
-    obj2->mamaposy = wcspos[0]*(MAMA_CORFLEX+1.0);
-    }
-
-  if (FLAG(obj2.mx2w)
-	|| FLAG(obj2.win_mx2w)
-	|| FLAG(obj2.poserr_mx2w)
-	|| FLAG(obj2.winposerr_mx2w)
-	|| FLAG(obj2.poserrmx2w_prof)
-	|| FLAG(obj2.prof_flagw)
-	|| ((!prefs.pixel_scale) && (FLAG(obj2.npixw)
-		|| FLAG(obj2.fdnpixw)
-		|| FLAG(obj2.fwhmw))))
-    {
-    rawpos[0] = obj2->posx;
-    rawpos[1] = obj2->posy;
-    pixscale2 = wcs_jacobian(wcs, rawpos, obj2->jacob);
-    }
-
-/* Express shape parameters in WORLD frame */
-  if (FLAG(obj2.mx2w))
-    astrom_shapeparam(field, obj);
-  if (FLAG(obj2.win_mx2w))
-    astrom_winshapeparam(field, obj);
-  if (FLAG(obj2.prof_flagw))
-    astrom_profshapeparam(field, obj);
-
-/* Express position error parameters in WORLD frame */
-  if (FLAG(obj2.poserr_mx2w))
-    astrom_errparam(field, obj);
-  if (FLAG(obj2.winposerr_mx2w))
-    astrom_winerrparam(field, obj);
-  if (FLAG(obj2.poserrmx2w_prof))
-    astrom_proferrparam(field, obj);
-
-  if (FLAG(obj2.npixw))
-    obj2->npixw = obj->npix * (prefs.pixel_scale?
-	field->pixscale/3600.0*field->pixscale/3600.0 : pixscale2);
-  if (FLAG(obj2.fdnpixw))
-    obj2->fdnpixw = obj->fdnpix * (prefs.pixel_scale?
-	field->pixscale/3600.0*field->pixscale/3600.0 : pixscale2);
-
-  if (FLAG(obj2.fwhmw))
-    obj2->fwhmw = obj->fwhm * (prefs.pixel_scale?
-	field->pixscale/3600.0 : sqrt(pixscale2));
-
   return;
   }
 
@@ -599,6 +703,84 @@ void	astrom_winerrparam(picstruct *field, objstruct *obj)
   }
 
 
+/***************************** astrom_psferrparam ***************************/
+/*
+Compute error ellipse parameters in WORLD and SKY coordinates.
+*/
+void	astrom_psferrparam(picstruct *field, objstruct *obj)
+  {
+   wcsstruct	*wcs;
+   double	dx2,dy2,dxy, xm2,ym2,xym, temp,pm2, lm0,lm1,lm2,lm3;
+   int		lng,lat, naxis;
+
+  wcs = field->wcs;
+  naxis = wcs->naxis;
+  lng = wcs->lng;
+  lat = wcs->lat;
+  if (lng == lat)
+    {
+    lng = 0;
+    lat = 1;
+    }
+  lm0 = obj2->jacob[lng+naxis*lng];
+  lm1 = obj2->jacob[lat+naxis*lng];
+  lm2 = obj2->jacob[lng+naxis*lat];
+  lm3 = obj2->jacob[lat+naxis*lat];
+
+/* All WORLD params based on 2nd order moments have to pass through here */
+  dx2 = obj2->poserrmx2_psf;
+  dy2 = obj2->poserrmy2_psf;
+  dxy = obj2->poserrmxy_psf;
+  obj2->poserrmx2w_psf = xm2 = lm0*lm0*dx2+lm1*lm1*dy2+lm0*lm1*dxy;
+  obj2->poserrmy2w_psf = ym2 = lm2*lm2*dx2+lm3*lm3*dy2+lm2*lm3*dxy;
+  obj2->poserrmxyw_psf = xym = lm0*lm2*dx2+lm1*lm3*dy2+(lm0*lm3+lm1*lm2)*dxy;
+  temp=xm2-ym2;
+  if (FLAG(obj2.poserrthetaw_psf))
+    {
+    obj2->poserrthetaw_psf = (fmod_m90_p90(temp==0.0)?
+				(45.0):(0.5*atan2(2.0*xym,temp)/DEG));
+
+/*-- Compute position angles in J2000 or B1950 reference frame */
+    if (wcs->lng != wcs->lat)
+      {
+      if (FLAG(obj2.poserrthetas_psf))
+        obj2->poserrthetas_psf = fmod_m90_p90(lng<lat?
+		((obj2->poserrthetaw_psf>0.0?90:-90.0)-obj2->poserrthetaw_psf)
+		: obj2->poserrthetaw_psf);
+      if (FLAG(obj2.poserrtheta2000_psf))
+        obj2->poserrtheta2000_psf = fmod_m90_p90(obj2->poserrthetas_psf
+				+ obj2->dtheta2000);
+      if (FLAG(obj2.poserrtheta1950_psf))
+        obj2->poserrtheta1950_psf = fmod_m90_p90(obj2->poserrthetas_psf
+				+ obj2->dtheta1950);
+      }
+    }
+
+  if (FLAG(obj2.poserraw_psf))
+    {
+    temp = sqrt(0.25*temp*temp+xym*xym);
+    pm2 = 0.5*(xm2+ym2);
+    obj2->poserraw_psf = (float)sqrt(pm2+temp);
+    obj2->poserrbw_psf = (float)sqrt(pm2-temp);
+    }
+
+  if (FLAG(obj2.poserrcxxw_psf))
+    {
+/*-- Handle large, fully correlated profiles (can cause a singularity...) */
+    if ((temp=xm2*ym2-xym*xym)<1e-6)
+      {
+      temp = 1e-6;
+      xym *= 0.99999;
+      }
+    obj2->poserrcxxw_psf = (float)(ym2/temp);
+    obj2->poserrcyyw_psf = (float)(xm2/temp);
+    obj2->poserrcxyw_psf = (float)(-2*xym/temp);
+    }
+
+  return;
+  }
+
+
 /***************************** astrom_proferrparam ***************************/
 /*
 Compute error ellipse parameters in WORLD and SKY coordinates.
@@ -684,7 +866,9 @@ Compute profile-fitting shape parameters in WORLD and SKY coordinates.
 void	astrom_profshapeparam(picstruct *field, objstruct *obj)
   {
    wcsstruct	*wcs;
-   double	dx2,dy2,dxy, xm2,ym2,xym, temp,pm2, lm0,lm1,lm2,lm3, ct,st;
+   double	mat[9], tempmat[9], mx2wcov[9], dpdmx2[6], cov[4],
+		dx2,dy2,dxy, xm2,ym2,xym, pm2, lm0,lm1,lm2,lm3, ct,st,
+		temp, invstemp, den, invden, dval;
    int		lng,lat, naxis;
 
   wcs = field->wcs;
@@ -744,7 +928,7 @@ void	astrom_profshapeparam(picstruct *field, objstruct *obj)
 	obj2->prof_spheroid_refferr/obj2->prof_spheroid_reff
 				*obj2->prof_spheroid_reffw
 	: 0.0;
-    obj2->prof_spheroid_aspectw = obj2->prof_spheroid_reffw>0.0?
+    obj2->prof_spheroid_aspectw = (obj2->prof_spheroid_reffw>0.0 && pm2>temp)?
 				  sqrt(pm2-temp) / obj2->prof_spheroid_reffw
 				: obj2->prof_spheroid_aspect;
     obj2->prof_spheroid_aspecterrw = obj2->prof_spheroid_aspect > 0.0?
@@ -796,7 +980,7 @@ void	astrom_profshapeparam(picstruct *field, objstruct *obj)
     obj2->prof_disk_scaleerrw = obj2->prof_disk_scale > 0.0?
 	obj2->prof_disk_scaleerr/obj2->prof_disk_scale*obj2->prof_disk_scalew
 	: 0.0;
-    obj2->prof_disk_aspectw = obj2->prof_disk_scalew>0.0?
+    obj2->prof_disk_aspectw = (obj2->prof_disk_scalew>0.0 && pm2>temp)?
 				  sqrt(pm2-temp) / obj2->prof_disk_scalew
 				: obj2->prof_disk_aspect;
     obj2->prof_disk_aspecterrw = obj2->prof_disk_aspect > 0.0?
@@ -871,6 +1055,133 @@ void	astrom_profshapeparam(picstruct *field, objstruct *obj)
 	: 0.0;
     }
 
+/* Global 2nd-order moments */
+  if (FLAG(obj2.prof_mx2w))
+    {
+    dx2 = obj2->prof_mx2;
+    dy2 = obj2->prof_my2;
+    dxy = obj2->prof_mxy;
+    mat[0] = lm0*lm0;
+    mat[3] = lm1*lm1;
+    mat[6] = lm0*lm1;
+    mat[1] = lm2*lm2;
+    mat[4] = lm3*lm3;
+    mat[7] = lm2*lm3;
+    mat[2] = lm0*lm2;
+    mat[5] = lm1*lm3;
+    mat[8] = lm0*lm3+lm1*lm2;
+    obj2->prof_mx2w = xm2 = mat[0]*dx2 + mat[3]*dy2 + mat[6]*dxy;
+    obj2->prof_my2w = ym2 = mat[1]*dx2 + mat[4]*dy2 + mat[7]*dxy;
+    obj2->prof_mxyw = xym = mat[2]*dx2 + mat[5]*dy2 + mat[8]*dxy;
+    temp=xm2-ym2;
+    if (FLAG(obj2.prof_thetaw))
+      {
+      obj2->prof_thetaw = fmod_m90_p90((temp == 0.0)?
+			(45.0) : (0.5*atan2(2.0*xym,temp)/DEG));
+
+/*---- Compute position angles in J2000 or B1950 reference frame */
+      if (wcs->lng != wcs->lat)
+        {
+        if (FLAG(obj2.prof_thetas))
+          obj2->prof_thetas = fmod_m90_p90(lng<lat?
+			((obj2->prof_thetaw>0.0?90:-90.0) - obj2->prof_thetaw)
+			: obj2->prof_thetaw);
+        if (FLAG(obj2.prof_theta2000))
+          obj2->prof_theta2000 = fmod_m90_p90(obj2->prof_thetas
+		+ obj2->dtheta2000);
+        if (FLAG(obj2.prof_theta1950))
+          obj2->prof_theta1950 = fmod_m90_p90(obj2->prof_thetas
+		+ obj2->dtheta1950);
+        }
+      }
+
+    if (FLAG(obj2.prof_aw))
+      {
+      temp = sqrt(0.25*temp*temp+xym*xym);
+      pm2 = 0.5*(xm2+ym2);
+      obj2->prof_aw = (float)sqrt(pm2+temp);
+      obj2->prof_bw = (float)sqrt(pm2-temp);
+      }
+
+    if (FLAG(obj2.prof_cxxw))
+      {
+/*---- Handle large, fully correlated profiles (can cause a singularity...) */
+      if ((temp=xm2*ym2-xym*xym)<1e-6)
+        {
+        temp = 1e-6;
+        xym *= 0.99999;
+        }
+      obj2->prof_cxxw = (float)(ym2/temp);
+      obj2->prof_cyyw = (float)(xm2/temp);
+      obj2->prof_cxyw = (float)(-2*xym/temp);
+      }
+  
+/*-- Use the Jacobians to compute the moment covariance matrix */
+    if (FLAG(obj2.prof_pol1errw) || FLAG(obj2.prof_e1errw))
+      propagate_covar(obj2->prof_mx2cov, mat, mx2wcov, 3, 3, tempmat);
+
+    if (FLAG(obj2.prof_pol1w))
+      {
+      if (xm2+ym2 > 1.0/BIG)
+        {
+        obj2->prof_pol1w = (xm2 - ym2) / (xm2+ym2);
+        obj2->prof_pol2w = 2.0*xym / (xm2 + ym2);
+        if (FLAG(obj2.prof_pol1errw))
+          {
+/*-------- Compute the Jacobian of polarisation */
+          invden = 1.0/(xm2+ym2);
+          dpdmx2[0] =  2.0*ym2*invden*invden;
+          dpdmx2[1] = -2.0*xm2*invden*invden;
+          dpdmx2[2] =  0.0;
+          dpdmx2[3] = -2.0*xym*invden*invden;
+          dpdmx2[4] = -2.0*xym*invden*invden;
+          dpdmx2[5] =  2.0*invden;
+          propagate_covar(mx2wcov, dpdmx2, cov, 3, 2, tempmat);
+          obj2->prof_pol1errw = (float)sqrt(cov[0]<0.0? 0.0: cov[0]);
+          obj2->prof_pol2errw = (float)sqrt(cov[3]<0.0? 0.0: cov[3]);
+          obj2->prof_pol12corrw = (dval=cov[0]*cov[3]) > 0.0?
+					(float)(cov[1]/sqrt(dval)) : 0.0;
+          }
+        }
+      else
+        obj2->prof_pol1w = obj2->prof_pol2w = obj2->prof_pol1errw
+		= obj2->prof_pol2errw = obj2->prof_pol12corrw = 0.0;
+      }
+
+    if (FLAG(obj2.prof_e1w))
+      {
+      if (xm2+ym2 > 1.0/BIG)
+        {
+        temp = xm2*ym2 - xym*xym;
+        den = (temp>=0.0) ? xm2+ym2+2.0*sqrt(temp) : xm2+ym2;
+        invden = 1.0/den;
+        obj2->prof_e1w = (float)(invden*(xm2 - ym2));
+        obj2->prof_e2w = (float)(2.0 * invden * xym);
+        if (FLAG(obj2.prof_e1errw))
+        {
+/*------ Compute the Jacobian of ellipticity */
+        invstemp = (temp>=0.0) ? 1.0/sqrt(temp) : 0.0;
+        dpdmx2[0] = ( den - (1.0+ym2*invstemp)*(xm2-ym2))*invden*invden;
+        dpdmx2[1] = (-den - (1.0+xm2*invstemp)*(xm2-ym2))*invden*invden;
+        dpdmx2[2] = 2.0*xym*invstemp*(xm2-ym2)*invden*invden;
+        dpdmx2[3] = -2.0*xym*(1.0+ym2*invstemp)*invden*invden;
+        dpdmx2[4] = -2.0*xym*(1.0+xm2*invstemp)*invden*invden;
+        dpdmx2[5] =  (2.0*den+4.0*xym*xym*invstemp)*invden*invden;
+
+/*------ Use the Jacobian to compute the ellipticity covariance matrix */
+        propagate_covar(mx2wcov, dpdmx2, cov, 3, 2, tempmat);
+        obj2->prof_e1errw = (float)sqrt(cov[0]<0.0? 0.0: cov[0]);
+        obj2->prof_e2errw = (float)sqrt(cov[3]<0.0? 0.0: cov[3]);
+        obj2->prof_e12corrw = (dval=cov[0]*cov[3]) > 0.0?
+					(float)(cov[1]/sqrt(dval)) : 0.0;
+        }
+        }
+      else
+        obj2->prof_e1w = obj2->prof_e2w = obj2->prof_e1errw
+		= obj2->prof_e2errw = obj2->prof_e12corrw = 0.0;
+      }
+    }
+
   return;
   }
 
