@@ -1,18 +1,30 @@
- /*
- 				back.c
-
-*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+/*
+*				back.c
 *
-*	Part of:	SExtractor
+* Functions dealing with the image background.
 *
-*	Author:		E.BERTIN (IAP)
+*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 *
-*	Contents:	functions dealing with background computation.
+*	This file part of:	SExtractor
 *
-*	Last modify:	27/10/2008
+*	Copyright:		(C) 1993-2011 Emmanuel Bertin -- IAP/CNRS/UPMC
 *
-*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-*/
+*	License:		GNU General Public License
+*
+*	SExtractor is free software: you can redistribute it and/or modify
+*	it under the terms of the GNU General Public License as published by
+*	the Free Software Foundation, either version 3 of the License, or
+*	(at your option) any later version.
+*	SExtractor is distributed in the hope that it will be useful,
+*	but WITHOUT ANY WARRANTY; without even the implied warranty of
+*	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+*	GNU General Public License for more details.
+*	You should have received a copy of the GNU General Public License
+*	along with SExtractor. If not, see <http://www.gnu.org/licenses/>.
+*
+*	Last modified:		23/03/2011
+*
+*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%*/
 
 #ifdef HAVE_CONFIG_H
 #include        "config.h"
@@ -36,7 +48,7 @@
 Background maps are established from the images themselves; thus we need to
 make at least one first pass through the data.
 */
-void	makeback(picstruct *field, picstruct *wfield)
+void	makeback(picstruct *field, picstruct *wfield, int wscale_flag)
 
   {
    backstruct	*backmesh,*wbackmesh, *bm,*wbm;
@@ -48,7 +60,7 @@ void	makeback(picstruct *field, picstruct *wfield)
 		w,bw, bh, nx,ny,nb,
 		lflag, nr;
    float	*ratio,*ratiop, *weight, *sigma,
-		sratio;
+		sratio, sigfac;
 
 /* If the weight-map is not an external one, no stats are needed for it */
   if (wfield && wfield->flags&(INTERP_FIELD|BACKRMS_FIELD))
@@ -296,18 +308,27 @@ void	makeback(picstruct *field, picstruct *wfield)
         *(ratiop++) = sratio;
         nr++;
         }
-    wfield->sigfac = hmedian(ratio, nr);
+    sigfac = fqmedian(ratio, nr);
     for (i=0; i<nr && ratio[i]<=0.0; i++);
     if (i<nr)
-      wfield->sigfac = hmedian(ratio+i, nr-i);
+      sigfac = fqmedian(ratio+i, nr-i);
     else
       {
       warning("Null or negative global weighting factor:","defaulted to 1");
-      wfield->sigfac = 1.0;
+      sigfac = 1.0;
       } 
     free(ratio);
+
+    if (wscale_flag)
+      wfield->sigfac = sigfac;
+    else
+      {
+      wfield->sigfac = 1.0;
+      field->backsig /= sigfac;
+      }
     }
 
+
 /* Compute 2nd derivatives along the y-direction */
   NFPRINTF(OUTPUT, "Computing background d-map");
   free(field->dback);
@@ -753,10 +774,10 @@ void	filterback(picstruct *field)
           smask[i++] = sigma[x+y];
           }
         }
-      if (fabs((med=hmedian(bmask, i))-back[px+py])>=fthresh)
+      if (fabs((med=fqmedian(bmask, i))-back[px+py])>=fthresh)
         {
         back2[px+py] = med;
-        sigma2[px+py] = hmedian(smask, i);
+        sigma2[px+py] = fqmedian(smask, i);
         }
       else
         {
@@ -769,17 +790,17 @@ void	filterback(picstruct *field)
   free(bmask);
   free(smask);
   memcpy(back, back2, np*sizeof(float));
-  field->backmean = hmedian(back2, np);
+  field->backmean = fqmedian(back2, np);
   free(back2);
   memcpy(sigma, sigma2, np*sizeof(float));
-  field->backsig = hmedian(sigma2, np);
+  field->backsig = fqmedian(sigma2, np);
 
   if (field->backsig<=0.0)
     {
     sigmat = sigma2+np;
     for (i=np; i-- && *(--sigmat)>0.0;);
     if (i>=0 && i<(np-1))
-      field->backsig = hmedian(sigmat+1, np-1-i);
+      field->backsig = fqmedian(sigmat+1, np-1-i);
     else
       {
       if (field->flags&(DETECT_FIELD|MEASURE_FIELD))
