@@ -1,18 +1,31 @@
 /*
- 				catout.c
+*				catout.c
+*
+* Functions related to catalogue output.
+*
+*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+*
+*	This file part of:	SExtractor
+*
+*	Copyright:		(C) 1993-2013 Emmanuel Bertin -- IAP/CNRS/UPMC
+*
+*	License:		GNU General Public License
+*
+*	SExtractor is free software: you can redistribute it and/or modify
+*	it under the terms of the GNU General Public License as published by
+*	the Free Software Foundation, either version 3 of the License, or
+*	(at your option) any later version.
+*	SExtractor is distributed in the hope that it will be useful,
+*	but WITHOUT ANY WARRANTY; without even the implied warranty of
+*	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+*	GNU General Public License for more details.
+*	You should have received a copy of the GNU General Public License
+*	along with SExtractor. If not, see <http://www.gnu.org/licenses/>.
+*
+*	Last modified:		12/09/2013
+*
+*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%*/
 
-*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-*
-*	Part of:	SExtractor
-*
-*	Author:		E.BERTIN (IAP)
-*
-*	Contents:	functions for output of catalog data.
-*
-*	Last modify:	18/03/2009
-*
-*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-*/
 #ifdef HAVE_CONFIG_H
 #include        "config.h"
 #endif
@@ -175,6 +188,11 @@ void	updateparamflags()
 			| FLAG(obj2.prof_disk_patternspiral);
   FLAG(obj2.prof_disk_scale) |= prefs.pattern_flag;
 
+  FLAG(obj2.prof_concentration) |= FLAG(obj2.prof_concentrationerr);
+  FLAG(obj2.fluxcorerr_prof) |= FLAG(obj2.magcorerr_prof);
+  FLAG(obj2.fluxcor_prof) |= FLAG(obj2.magcor_prof)
+			| FLAG(obj2.fluxcorerr_prof);
+
   FLAG(obj2.poserraw_prof) |= FLAG(obj2.poserrbw_prof);
   FLAG(obj2.poserrcxxw_prof) |= FLAG(obj2.poserrcyyw_prof)
 			| FLAG(obj2.poserrcxyw_prof);
@@ -192,6 +210,9 @@ void	updateparamflags()
 			| FLAG(obj2.poserraw_prof);
   FLAG(obj2.poserrcxx_prof) |= FLAG(obj2.poserrcyy_prof)
 			| FLAG(obj2.poserrcxy_prof);
+  FLAG(obj2.poserrmx2_prof) |= FLAG(obj2.poserrmy2_prof)
+			| FLAG(obj2.poserrmxy_prof)
+			| FLAG(obj2.poserrmx2w_prof);
   FLAG(obj2.alpha1950_prof) |= FLAG(obj2.delta1950_prof)
 			| FLAG(obj2.poserrtheta1950_prof);
   FLAG(obj2.alpha2000_prof) |= FLAG(obj2.delta2000_prof)
@@ -201,31 +222,57 @@ void	updateparamflags()
 			| FLAG(obj2.alpha2000_prof);
   FLAG(obj2.xw_prof) |= FLAG(obj2.yw_prof)
 			| FLAG(obj2.alphas_prof);
-
+  FLAG(obj2.xf_prof) |= FLAG(obj2.yf_prof);
   FLAG(obj2.x_prof) |= FLAG(obj2.y_prof)
 			| FLAG(obj2.xw_prof)
+			| FLAG(obj2.xf_prof)
 			| FLAG(obj2.poserra_prof)
 			| FLAG(obj2.poserrcxx_prof)
+			| FLAG(obj2.poserrmx2_prof)
 			| FLAG(obj2.prof_concentration)
-			| FLAG(obj2.prof_class_star);
-  FLAG(obj2.mag_prof) |= FLAG(obj2.magerr_prof);
-  FLAG(obj2.flux_prof) |= FLAG(obj2.mag_prof) | FLAG(obj2.fluxerr_prof);
+			| FLAG(obj2.prof_class_star)
+			| FLAG(obj2.fluxcor_prof);
+
+  FLAG(obj2.prof_dirac_fluxratio) |= FLAG(obj2.prof_dirac_fluxratioerr);
+  FLAG(obj2.prof_dirac_mag) |= FLAG(obj2.prof_dirac_magerr);
+  FLAG(obj2.prof_spheroid_fluxratio) |= FLAG(obj2.prof_spheroid_fluxratioerr);
   FLAG(obj2.prof_spheroid_mag) |= FLAG(obj2.prof_spheroid_magerr);
   FLAG(obj2.prof_spheroid_reff) |= FLAG(obj2.prof_spheroid_refferr);
   FLAG(obj2.prof_spheroid_aspect) |= FLAG(obj2.prof_spheroid_aspecterr);
   FLAG(obj2.prof_spheroid_theta) |= FLAG(obj2.prof_spheroid_thetaerr);
   FLAG(obj2.prof_spheroid_sersicn) |= FLAG(obj2.prof_spheroid_sersicnerr);
+  FLAG(obj2.prof_disk_fluxratio) |= FLAG(obj2.prof_disk_fluxratioerr);
   FLAG(obj2.prof_disk_mag) |= FLAG(obj2.prof_disk_magerr);
   FLAG(obj2.prof_disk_scale) |= FLAG(obj2.prof_disk_scaleerr);
   FLAG(obj2.prof_disk_aspect) |= FLAG(obj2.prof_disk_aspecterr);
   FLAG(obj2.prof_disk_inclination) |= FLAG(obj2.prof_disk_inclinationerr);
   FLAG(obj2.prof_disk_theta) |= FLAG(obj2.prof_disk_thetaerr);
+  FLAG(obj2.prof_bar_fluxratio) |= FLAG(obj2.prof_bar_fluxratioerr);
   FLAG(obj2.prof_bar_mag) |= FLAG(obj2.prof_bar_magerr);
   FLAG(obj2.prof_bar_length) |= FLAG(obj2.prof_bar_lengtherr);
   FLAG(obj2.prof_bar_aspect) |= FLAG(obj2.prof_bar_aspecterr);
   FLAG(obj2.prof_bar_theta) |= FLAG(obj2.prof_bar_thetaerr);
+  FLAG(obj2.prof_arms_fluxratio) |= FLAG(obj2.prof_arms_fluxratioerr);
   FLAG(obj2.prof_arms_mag) |= FLAG(obj2.prof_arms_magerr);
-  FLAG(obj2.dtheta1950) |= FLAG(obj2.prof_spheroid_theta1950)
+  FLAG(obj2.prof_e1errw) |= FLAG(obj2.prof_e2errw) | FLAG(obj2.prof_e12corrw);
+  FLAG(obj2.prof_e1w) |= FLAG(obj2.prof_e2w) | FLAG(obj2.prof_e1errw);
+  FLAG(obj2.prof_pol1errw) |= FLAG(obj2.prof_pol2errw)
+			| FLAG(obj2.prof_pol12corrw);
+  FLAG(obj2.prof_pol1w) |= FLAG(obj2.prof_pol2w) | FLAG(obj2.prof_pol1errw);
+  FLAG(obj2.prof_aw) |= FLAG(obj2.prof_bw);
+  FLAG(obj2.prof_cxxw) |= FLAG(obj2.prof_cyyw) | FLAG(obj2.prof_cxyw);
+  FLAG(obj2.prof_thetas) |= FLAG(obj2.prof_theta1950)
+			| FLAG(obj2.prof_theta2000);
+  FLAG(obj2.prof_thetaw) |= FLAG(obj2.prof_thetas);
+
+  FLAG(obj2.prof_mx2w) |= FLAG(obj2.prof_my2w)
+			| FLAG(obj2.prof_mxyw)
+			| FLAG(obj2.prof_thetaw) | FLAG(obj2.prof_aw)
+			| FLAG(obj2.prof_cxxw)
+			| FLAG(obj2.prof_e1w) | FLAG(obj2.prof_pol1w);
+
+  FLAG(obj2.dtheta1950) |= FLAG(obj2.prof_theta1950)
+			| FLAG(obj2.prof_spheroid_theta1950)
 			| FLAG(obj2.prof_disk_theta1950)
 //			| FLAG(obj2.prof_arms_theta1950)
 			| FLAG(obj2.prof_bar_theta1950)
@@ -235,7 +282,8 @@ void	updateparamflags()
 			| FLAG(obj2.poserr_theta1950)
 			| FLAG(obj2.theta1950)
 			| FLAG(obj2.poserrtheta1950_prof);
-  FLAG(obj2.dtheta2000) |= FLAG(obj2.prof_spheroid_theta2000)
+  FLAG(obj2.dtheta2000) |= FLAG(obj2.prof_theta2000)
+			| FLAG(obj2.prof_spheroid_theta2000)
 			| FLAG(obj2.prof_disk_theta2000)
 //			| FLAG(obj2.prof_arms_theta2000)
 			| FLAG(obj2.prof_bar_theta2000)
@@ -277,6 +325,11 @@ void	updateparamflags()
 			| FLAG(obj2.prof_disk_aspecterrw)
 			| FLAG(obj2.prof_disk_thetaerrw)
 			| FLAG(obj2.prof_arms_scalew);
+  FLAG(obj2.prof_disk_fluxmean) |= FLAG(obj2.prof_disk_mumean);
+  FLAG(obj2.prof_disk_fluxeff) |= FLAG(obj2.prof_disk_mueff);
+  FLAG(obj2.prof_disk_peak) |= FLAG(obj2.prof_disk_mumax)
+				| FLAG(obj2.prof_disk_fluxeff)
+				| FLAG(obj2.prof_disk_fluxmean);
 
   FLAG(obj2.prof_spheroid_reffw) |= FLAG(obj2.prof_spheroid_aspectw)
 			| FLAG(obj2.prof_spheroid_thetaw)
@@ -284,16 +337,47 @@ void	updateparamflags()
 			| FLAG(obj2.prof_spheroid_aspecterrw)
 			| FLAG(obj2.prof_spheroid_thetaerrw);
 
+  FLAG(obj2.prof_spheroid_fluxmean) |= FLAG(obj2.prof_spheroid_mumean);
+  FLAG(obj2.prof_spheroid_fluxeff) |= FLAG(obj2.prof_spheroid_mueff);
+  FLAG(obj2.prof_spheroid_peak) |= FLAG(obj2.prof_spheroid_mumax)
+				| FLAG(obj2.prof_spheroid_fluxeff)
+				| FLAG(obj2.prof_spheroid_fluxmean);
+
   FLAG(obj2.prof_flagw) |= FLAG(obj2.prof_spheroid_reffw)
 			| FLAG(obj2.prof_disk_scalew)
 			| FLAG(obj2.prof_bar_lengthw)
-			| FLAG(obj2.prof_arms_scalew);
+			| FLAG(obj2.prof_arms_scalew)
+			| FLAG(obj2.prof_mx2w);
+
+  FLAG(obj2.prof_e1err) |= FLAG(obj2.prof_e2err) | FLAG(obj2.prof_e12corr)
+			| FLAG(obj2.prof_e1errw);
 			
+  FLAG(obj2.prof_e1) |= FLAG(obj2.prof_e2)
+			| FLAG(obj2.prof_e1err) | FLAG(obj2.prof_e1w);
+  FLAG(obj2.prof_pol1err) |= FLAG(obj2.prof_pol2err)
+			| FLAG(obj2.prof_pol12corr) | FLAG(obj2.prof_pol1errw);
+  FLAG(obj2.prof_pol1) |= FLAG(obj2.prof_pol2)
+			| FLAG(obj2.prof_pol1err) | FLAG(obj2.prof_pol1w);
+  FLAG(obj2.prof_a) |= FLAG(obj2.prof_b) | FLAG(obj2.prof_theta)
+			| FLAG(obj2.prof_aw);
+  FLAG(obj2.prof_cxx) |= FLAG(obj2.prof_cyy)
+			| FLAG(obj2.prof_cxy) | FLAG(obj2.prof_cxxw);
   FLAG(obj2.prof_mx2) |= FLAG(obj2.prof_my2) | FLAG(obj2.prof_mxy)
-			| FLAG(obj2.prof_e1) |FLAG(obj2.prof_e2)
-			| FLAG(obj2.prof_eps1) |FLAG(obj2.prof_eps2);
+			| FLAG(obj2.prof_e1) | FLAG(obj2.prof_pol1)
+			| FLAG(obj2.prof_a) | FLAG(obj2.prof_cxx)
+			| FLAG(obj2.prof_mx2w);
+  FLAG(obj2.prof_conva) |= FLAG(obj2.prof_convb) | FLAG(obj2.prof_convtheta);
+  FLAG(obj2.prof_convcxx) |= FLAG(obj2.prof_convcyy)
+			/*| FLAG(obj2.fluxcor_prof) */;
+  FLAG(obj2.prof_convmx2) |= FLAG(obj2.prof_convcxx) | FLAG(obj2.prof_conva);
+  FLAG(obj2.fluxmean_prof) |= FLAG(obj2.mumean_prof);
+  FLAG(obj2.peak_prof) |= FLAG(obj2.mumax_prof);
+  FLAG(obj2.fluxeff_prof) |= FLAG(obj2.mueff_prof)
+			| FLAG(obj2.fluxmean_prof) | FLAG(obj2.peak_prof);
+
   FLAG(obj2.prof_arms_flux) |= FLAG(obj2.prof_arms_fluxerr)
 			| FLAG(obj2.prof_arms_mag)
+			| FLAG(obj2.prof_arms_fluxratio)
 			| FLAG(obj2.prof_arms_scalew)
 			| FLAG(obj2.prof_arms_scale)
 			| FLAG(obj2.prof_arms_posang)
@@ -303,6 +387,7 @@ void	updateparamflags()
   FLAG(obj2.prof_bar_theta) |= FLAG(obj2.prof_bar_lengthw);
   FLAG(obj2.prof_bar_flux) |= FLAG(obj2.prof_bar_fluxerr)
 			| FLAG(obj2.prof_bar_mag)
+			| FLAG(obj2.prof_bar_fluxratio)
 			| FLAG(obj2.prof_bar_lengthw)
 			| FLAG(obj2.prof_bar_length)
 			| FLAG(obj2.prof_bar_aspect)
@@ -311,30 +396,67 @@ void	updateparamflags()
 			| FLAG(obj2.prof_arms_flux);
   FLAG(obj2.prof_disk_flux) |= FLAG(obj2.prof_disk_fluxerr)
 			| FLAG(obj2.prof_disk_mag)
+			| FLAG(obj2.prof_disk_fluxratio)
 			| FLAG(obj2.prof_disk_scalew)
 			| FLAG(obj2.prof_disk_scale)
 			| FLAG(obj2.prof_disk_aspect)
 			| FLAG(obj2.prof_disk_inclination)
 			| FLAG(obj2.prof_disk_theta)
+			| FLAG(obj2.prof_disk_peak)
 			| FLAG(obj2.prof_bar_flux);
   FLAG(obj2.prof_spheroid_flux) |= FLAG(obj2.prof_spheroid_fluxerr)
 			| FLAG(obj2.prof_spheroid_mag)
+			| FLAG(obj2.prof_spheroid_fluxratio)
 			| FLAG(obj2.prof_spheroid_reffw)
 			| FLAG(obj2.prof_spheroid_reff)
 			| FLAG(obj2.prof_spheroid_aspect)
 			| FLAG(obj2.prof_spheroid_theta)
-			| FLAG(obj2.prof_spheroid_sersicn);
+			| FLAG(obj2.prof_spheroid_sersicn)
+			| FLAG(obj2.prof_spheroid_peak);
+  FLAG(obj2.prof_dirac_flux) |= FLAG(obj2.prof_dirac_fluxerr)
+			| FLAG(obj2.prof_dirac_mag)
+			| FLAG(obj2.prof_dirac_fluxratio);
+  FLAG(obj2.prof_offset_flux) |= FLAG(obj2.prof_offset_fluxerr);
+  FLAG(obj2.fluxerr_dprof) |= FLAG(obj2.magerr_dprof);
+  FLAG(obj2.flux_dprof) |= FLAG(obj2.mag_dprof)
+			| FLAG(obj2.fluxerr_dprof);
+  prefs.dprof_flag |= FLAG(obj2.dprof_chi2)
+			| FLAG(obj2.dprof_flag)
+			| FLAG(obj2.dprof_niter)
+			| FLAG(obj2.flux_dprof);
+
+  FLAG(obj2.fluxerr_prof) |= FLAG(obj2.magerr_prof)
+			| FLAG(obj2.prof_concentrationerr)
+			| FLAG(obj2.fluxcorerr_prof)
+			| FLAG(obj2.prof_arms_fluxratio)
+			| FLAG(obj2.prof_bar_fluxratio)
+			| FLAG(obj2.prof_disk_fluxratio)
+			| FLAG(obj2.prof_spheroid_fluxratio)
+			| FLAG(obj2.prof_dirac_fluxratio);
+  FLAG(obj2.flux_prof) |= FLAG(obj2.mag_prof)
+			| FLAG(obj2.fluxerr_prof)
+			| FLAG(obj2.fluxcor_prof);
+
   prefs.prof_flag |= FLAG(obj2.prof_chi2) | FLAG(obj2.prof_niter)
 			| FLAG(obj2.prof_vector) | FLAG(obj2.prof_errvector)
+			| FLAG(obj2.prof_errmatrix)
 			| FLAG(obj2.x_prof) | FLAG(obj2.y_prof)
+			| FLAG(obj2.prof_flag)
+			| FLAG(obj2.flux_prof)
 			| FLAG(obj2.prof_mx2)
+			| FLAG(obj2.fluxeff_prof)
 			| FLAG(obj2.prof_disk_flux)
-			| FLAG(obj2.prof_spheroid_flux);
+			| FLAG(obj2.prof_spheroid_flux)
+			| FLAG(obj2.prof_dirac_flux)
+			| FLAG(obj2.prof_offset_flux)
+			| prefs.dprof_flag;
 
 
 /* If only global parameters are requested, fit a Sersic model */
   if (prefs.prof_flag && !(FLAG(obj2.prof_spheroid_flux)
-			| FLAG(obj2.prof_disk_flux)))
+			| FLAG(obj2.prof_disk_flux)
+			| FLAG(obj2.prof_dirac_flux)
+			| FLAG(obj2.prof_offset_flux)))
     {
     FLAG(obj2.prof_spheroid_flux) |= prefs.prof_flag;
     FLAG(obj2.prof_spheroid_sersicn) |= prefs.prof_flag;
@@ -391,6 +513,7 @@ void	updateparamflags()
 			| FLAG(obj2.winposerr_theta2000);
   FLAG(obj2.winpos_alphas) |= FLAG(obj2.winpos_deltas)
 			| FLAG(obj2.winpos_alpha2000);
+  FLAG(obj2.winpos_xf) |= FLAG(obj2.winpos_yf);
   FLAG(obj2.winpos_xw) |= FLAG(obj2.winpos_yw)
 			| FLAG(obj2.winpos_alphas);
 
@@ -427,23 +550,35 @@ void	updateparamflags()
   FLAG(obj2.cxxw) |= FLAG(obj2.cyyw) | FLAG(obj2.cxyw);
 
   FLAG(obj2.mx2w) |= FLAG(obj2.my2w) | FLAG(obj2.mxyw)
-			| FLAG(obj2.thetaw) | FLAG(obj2.aw) | FLAG(obj2.cxxw)
-			| FLAG(obj2.npixw) | FLAG(obj2.fdnpixw)
-			| FLAG(obj2.fwhmw);
+			| FLAG(obj2.thetaw) | FLAG(obj2.aw) | FLAG(obj2.cxxw);
   
+  FLAG(obj2.peakxw) |= FLAG(obj2.peakyf);
   FLAG(obj2.peakxw) |= FLAG(obj2.peakyw) | FLAG(obj2.peakalphas);
-  FLAG(obj.peakx) |= FLAG(obj.peaky) | FLAG(obj2.peakxw);
+  FLAG(obj.peakx) |= FLAG(obj.peaky) | FLAG(obj2.peakxw) | FLAG(obj2.peakxf);
+
+  FLAG(obj2.mxf) |= FLAG(obj2.myf);
 
   FLAG(obj2.mxw) |= FLAG(obj2.myw) | FLAG(obj2.mx2w) | FLAG(obj2.alphas)
-		| FLAG(obj2.poserr_mx2w);
+		| FLAG(obj2.poserr_mx2w)
+		| ((FLAG(obj2.assoc) | FLAG(obj2.assoc_number))
+			&& (prefs.assoccoord_type==ASSOCCOORD_WORLD));
   FLAG(obj2.mamaposx) |= FLAG(obj2.mamaposy);
+  FLAG(obj2.fluxerr_win) |= FLAG(obj2.snr_win);
   FLAG(obj2.flux_win) |= FLAG(obj2.mag_win)|FLAG(obj2.magerr_win)
-			    | FLAG(obj2.flux_win) | FLAG(obj2.fluxerr_win);
+			| FLAG(obj2.flux_win) | FLAG(obj2.fluxerr_win);
   FLAG(obj2.winpos_x) |= FLAG(obj2.winpos_y)
 			| FLAG(obj2.winposerr_mx2) | FLAG(obj2.win_mx2)
-			| FLAG(obj2.winpos_xw) | FLAG(obj2.win_flag)
+			| FLAG(obj2.winpos_xw) | FLAG(obj2.winpos_xf)
+			| FLAG(obj2.win_flag)
 			| FLAG(obj2.flux_win) |FLAG(obj2.winpos_niter);
 
+  FLAG(obj2.area_flagw) |= FLAG(obj2.npixw) | FLAG(obj2.fdnpixw)
+			| FLAG(obj2.fwhmw)
+			| FLAG(obj2.maxmu) | FLAG(obj2.threshmu)
+			| FLAG(obj2.prof_spheroid_mumax)
+			| FLAG(obj2.prof_disk_mumax)
+			| FLAG(obj2.mumax_prof);
+
 /*------------------------------ Photometry ---------------------------------*/
 
   FLAG(obj2.fluxerr_best) |= FLAG(obj2.magerr_best);
@@ -457,7 +592,8 @@ void	updateparamflags()
 			| FLAG(obj2.kronfactor)
 			| FLAG(obj2.flux_best)
 			| FLAG(obj2.flux_radius)
-			| FLAG(obj2.hl_radius);
+			| FLAG(obj2.hl_radius)
+			| FLAG(obj2.fluxcor_prof);
   FLAG(obj2.flux_petro) |= FLAG(obj2.mag_petro) | FLAG(obj2.magerr_petro)
 			| FLAG(obj2.fluxerr_petro)
 			| FLAG(obj2.petrofactor);
@@ -478,6 +614,7 @@ void	updateparamflags()
   VECFLAG(obj.imaflag) |= VECFLAG(obj.imanflag);
 
 /*------------------------------ PSF-fitting --------------------------------*/
+  FLAG(obj2.fwhm_psf) |= FLAG(obj2.fwhmw_psf);
   FLAG(obj2.poserraw_psf) |= FLAG(obj2.poserrbw_psf);
   FLAG(obj2.poserrcxxw_psf) |= FLAG(obj2.poserrcyyw_psf)
 			| FLAG(obj2.poserrcxyw_psf);
@@ -534,6 +671,8 @@ void	updateparamflags()
   for (i=0; i<NISO; i++)
     FLAG(obj.iso[0]) |= FLAG(obj.iso[i]);
 
+  FLAG(obj.wflag) |= FLAG(obj.nzwpix) | FLAG(obj.nzdwpix);
+
   return; 
   }
 
@@ -548,10 +687,10 @@ void	dumpparams(void)
 
   for (i=0; *objkey[i].name ; i++)
     if (*objkey[i].unit)
-      printf("#%-22.22s %-58.58s [%s]\n",
+      printf("#%-24.24s %-57.57s [%s]\n",
 		objkey[i].name, objkey[i].comment, objkey[i].unit);
     else
-      printf("#%-22.22s %-58.58s\n",
+      printf("#%-24.24s %-57.57s\n",
 		objkey[i].name, objkey[i].comment);
 
   return;
@@ -579,6 +718,7 @@ void	initcat(void)
     else
       if (!(ascfile = fopen(prefs.cat_name, "w+")))
         error(EXIT_FAILURE,"*Error*: cannot open ", prefs.cat_name);
+//  setlinebuf(ascfile);
     if (prefs.cat_type == ASCII_HEAD && (key = objtab->key))
       for (i=0,n=1; i++<objtab->nkey; key=key->nextkey)
         {
@@ -793,6 +933,8 @@ void	reinitcat(picstruct *field)
     init_writeobj(fitscat, objtab, &buf);
     }
 
+  zerocat();
+
   return;
   }
 
@@ -961,3 +1103,21 @@ void	reendcat()
   }
 
 
+/********************************** zerocat **********************************/
+/*
+Reset to 0 all measurements in the current catalog.
+*/
+void	zerocat(void)
+  {
+   keystruct	*key;
+   int		i;
+
+  key = objtab->key;
+  for (i=objtab->nkey; i--; key=key->nextkey)
+    memset(key->ptr, 0, key->nbytes);
+
+  return;
+  }
+
+
+
