@@ -1,18 +1,30 @@
- /*
- 				field.c
-
-*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+/*
+*				field.c
 *
-*	Part of:	SExtractor
+* Handle field (image) structures.
 *
-*	Author:		E.BERTIN (IAP)
+*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 *
-*	Contents:	Handling of field structures.
+*	This file part of:	SExtractor
 *
-*	Last modify:	19/12/2007
+*	Copyright:		(C) 1993-2012 Emmanuel Bertin -- IAP/CNRS/UPMC
 *
-*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-*/
+*	License:		GNU General Public License
+*
+*	SExtractor is free software: you can redistribute it and/or modify
+*	it under the terms of the GNU General Public License as published by
+*	the Free Software Foundation, either version 3 of the License, or
+*	(at your option) any later version.
+*	SExtractor is distributed in the hope that it will be useful,
+*	but WITHOUT ANY WARRANTY; without even the implied warranty of
+*	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+*	GNU General Public License for more details.
+*	You should have received a copy of the GNU General Public License
+*	along with SExtractor. If not, see <http://www.gnu.org/licenses/>.
+*
+*	Last modified:		12/07/2012
+*
+*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%*/
 
 #ifdef HAVE_CONFIG_H
 #include        "config.h"
@@ -33,21 +45,22 @@
 #include	"field.h"
 #include	"filter.h"
 #include	"fitswcs.h"
+#include	"header.h"
 #include	"interpolate.h"
 
 /********************************* newfield **********************************/
 /*
-Returns a pointer to a new field, ready to go!
+Returns a pointer to a new field for extension ext, ready to go!
 */
-picstruct	*newfield(char *filename, int flags, int nok)
+picstruct	*newfield(char *filename, int flags, int ext)
 
   {
    picstruct	*field;
    catstruct	*cat;
    tabstruct	*tab;
-   int		nok2, ntab, margin;
+   char		*pstr;
+   int		ext2, nok, ntab, margin;
 
-/* Move to nok'th valid FITS image extension */
   if (!(cat = read_cat(filename)))
     error(EXIT_FAILURE, "*Error*: cannot open ", filename);
 
@@ -55,18 +68,25 @@ picstruct	*newfield(char *filename, int flags, int nok)
   QCALLOC(field, picstruct, 1);
   field->flags = flags;
   field->cat = cat;
+  nok = 0;
   tab = cat->tab;
-  nok++;	/* At least one pass through the loop */
-  nok2 = nok;
-  for (ntab=cat->ntab; nok && ntab--; tab=tab->nexttab)
+  if (tab->naxis >= 2
+	&& strncmp(tab->xtension, "BINTABLE", 8)
+	&& strncmp(tab->xtension, "ASCTABLE", 8))
+    nok++;
+  ext2 = ext;
+  for (ntab=cat->ntab; ext2-- && ntab--;)
     {
-    if ((tab->naxis < 2)
-	|| !strncmp(tab->xtension, "BINTABLE", 8)
-	|| !strncmp(tab->xtension, "ASCTABLE", 8))
-      continue;
-    field->tab = tab;
-    nok--;
+    tab=tab->nexttab;
+    if (tab->naxis >= 2
+	&& strncmp(tab->xtension, "BINTABLE", 8)
+	&& strncmp(tab->xtension, "ASCTABLE", 8))
+      nok++;
     }
+  if (!nok)
+    error(EXIT_FAILURE, "Not a valid FITS image in ",filename);
+
+  field->tab = tab;
   if (ntab<0)
     error(EXIT_FAILURE, "Not enough valid FITS image extensions in ",filename);
 
@@ -77,27 +97,37 @@ picstruct	*newfield(char *filename, int flags, int nok)
   else
     field->rfilename++;
 
+/* Create a file name with a "header" extension */
+  strcpy(field->hfilename, filename);
+  if (!(pstr = strrchr(field->hfilename, '.')))
+    pstr = field->hfilename+strlen(field->hfilename);
+  sprintf(pstr, "%s", prefs.head_suffix);
+
   sprintf(gstr, "Looking for %s", field->rfilename);
   NFPRINTF(OUTPUT, gstr);
 /* Check the image exists and read important info (image size, etc...) */
   field->file = cat->file;
-  
+
+  field->headflag = !read_aschead(field->hfilename, nok, field->tab);
   readimagehead(field);
 
   if (cat->ntab>1)
-    sprintf(gstr, "[%d/%d]", nok2, cat->tab->naxis<2? cat->ntab-1 : cat->ntab);
-  QPRINTF(OUTPUT, "%s \"%.20s\" %s / %d x %d / %d bits %s data\n",
+    sprintf(gstr, " [%d/%d]", ext, cat->tab->naxis<2? cat->ntab-1 : cat->ntab);
+  QPRINTF(OUTPUT, "----- %s %s%s\n",
 	flags&FLAG_FIELD?   "Flagging  from:" :
        (flags&(RMS_FIELD|VAR_FIELD|WEIGHT_FIELD)?
 			     "Weighting from:" :
        (flags&MEASURE_FIELD? "Measuring from:" :
 			     "Detecting from:")),
+	field->rfilename,
+        cat->ntab>1? gstr : "");
+  QPRINTF(OUTPUT, "      \"%.20s\" / %s / %dx%d / %d bits %s\n",
 	field->ident,
-        cat->ntab>1? gstr : "",
+	field->headflag? "EXT. HEADER" : "no ext. header",
 	field->width, field->height, field->bytepix*8,
 	field->bitpix>0?
-	(field->tab->compress_type!=COMPRESS_NONE?"COMPRESSED":"INTEGER")
-	:"FLOATING POINT");
+	(field->tab->compress_type!=COMPRESS_NONE?"(compressed)":"(integers)")
+	:"(floats)");
 
 /* Check the astrometric system and do the setup of the astrometric stuff */
   if (prefs.world_flag && (flags & (MEASURE_FIELD|DETECT_FIELD)))
@@ -153,9 +183,10 @@ picstruct	*newfield(char *filename, int flags, int nok)
   if (prefs.filter_flag)
     {
 /*-- If filtering is on, one should consider the height of the conv. mask */
+/*-- + 1 line for detectinhg zero-weight neighbours */
     if (field->stripheight < thefilter->convh)
       field->stripheight = thefilter->convh;
-    if (field->stripmargin < (margin = (thefilter->convh-1)/2))
+    if (field->stripmargin < (margin = (thefilter->convh-1)/2+1))
       field->stripmargin = margin;
     }
 
