@@ -1,18 +1,30 @@
 /*
- 				makeit.c
-
-*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+*				makeit.c
 *
-*	Part of:	SExtractor
+* Main program.
 *
-*	Author:		E.BERTIN, IAP & Leiden observatory
+*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 *
-*	Contents:	main program.
+*	This file part of:	SExtractor
 *
-*	Last modify:	20/11/2008
+*	Copyright:		(C) 1993-2013 Emmanuel Bertin -- IAP/CNRS/UPMC
 *
-*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-*/
+*	License:		GNU General Public License
+*
+*	SExtractor is free software: you can redistribute it and/or modify
+*	it under the terms of the GNU General Public License as published by
+*	the Free Software Foundation, either version 3 of the License, or
+*	(at your option) any later version.
+*	SExtractor is distributed in the hope that it will be useful,
+*	but WITHOUT ANY WARRANTY; without even the implied warranty of
+*	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+*	GNU General Public License for more details.
+*	You should have received a copy of the GNU General Public License
+*	along with SExtractor. If not, see <http://www.gnu.org/licenses/>.
+*
+*	Last modified:		17/08/2013
+*
+*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%*/
 
 #ifdef HAVE_CONFIG_H
 #include        "config.h"
@@ -45,8 +57,13 @@
 
 static int		selectext(char *filename);
 time_t			thetimet, thetimet2;
-extern profitstruct	*theprofit;
+#ifdef USE_MODEL
+extern profitstruct	*theprofit,*thedprofit, *thepprofit,*theqprofit;
+#else
+profitstruct	*theprofit,*thedprofit, *thepprofit,*theqprofit;
+#endif
 extern char		profname[][32];
+double			dtime;
 
 /******************************** makeit *************************************/
 /*
@@ -62,14 +79,16 @@ void	makeit()
    patternstruct	*pattern;
    static time_t        thetime1, thetime2;
    struct tm		*tm;
-   int			nflag[MAXFLAG],
+   unsigned int		modeltype;
+   int			nflag[MAXFLAG], nparam2[2],
 			i, nok, ntab, next, ntabmax, forcextflag,
-			nima0,nima1, nweight0,nweight1, npat;
+			nima0,nima1, nweight0,nweight1, npsf0,npsf1, npat,npat0;
 
 /* Install error logging */
   error_installfunc(write_error);
 
 /* Processing start date and time */
+  dtime = counter_seconds();
   thetimet = time(NULL);
   tm = localtime(&thetimet);
   sprintf(prefs.sdate_start,"%04d-%02d-%02d",
@@ -93,12 +112,40 @@ void	makeit()
   readcatparams(prefs.param_name);
   useprefs();			/* update things accor. to prefs parameters */
 
-  if (prefs.psf_flag || prefs.prof_flag)
+/* Check if a specific extension should be loaded */
+  if ((nima0=selectext(prefs.image_name[0])) != RETURN_ERROR)
     {
+    forcextflag = 1;
+    ntabmax = next = 1;
+    }
+  else
+    forcextflag = 0;
+
+/* Do the same for other data (but do not force single extension mode) */
+  nima1 = selectext(prefs.image_name[1]);
+  nweight0 = selectext(prefs.wimage_name[0]);
+  nweight1 = selectext(prefs.wimage_name[1]);
+  if (prefs.dpsf_flag)
+    {
+    npsf0 = selectext(prefs.psf_name[0]);
+    npsf1 = selectext(prefs.psf_name[1]);
+    }
+  else
+    npsf0 = selectext(prefs.psf_name[0]);
+  for (i=0; i<prefs.nfimage_name; i++)
+    nflag[i] = selectext(prefs.fimage_name[i]);
+
+  if (prefs.psf_flag)
+    {
+/*-- Read the first PSF extension to set up stuff such as context parameters */
     NFPRINTF(OUTPUT, "Reading PSF information");
-    thepsf = psf_load(prefs.psf_name[0]); 
     if (prefs.dpsf_flag)
-      ppsf = psf_load(prefs.psf_name[1]);
+      {
+      thedpsf = psf_load(prefs.psf_name[0],nima0<0? 1 :(npsf0<0? 1:npsf0)); 
+      thepsf = psf_load(prefs.psf_name[1], nima1<0? 1 :(npsf1<0? 1:npsf1));
+      }
+    else
+      thepsf = psf_load(prefs.psf_name[0], nima0<0? 1 :(npsf0<0? 1:npsf0)); 
  /*-- Need to check things up because of PSF context parameters */
     updateparamflags();
     useprefs();
@@ -106,22 +153,35 @@ void	makeit()
 
   if (prefs.prof_flag)
     {
-    fft_init();
+#ifdef USE_MODEL
+    fft_init(prefs.nthreads);
 /* Create profiles at full resolution */
     NFPRINTF(OUTPUT, "Preparing profile models");
-    theprofit = profit_init(thepsf);
-    changecatparamarrays("VECTOR_PROF", &theprofit->nparam, 1);
-    changecatparamarrays("VECTOR_PROFERR", &theprofit->nparam, 1);
+    modeltype = (FLAG(obj2.prof_offset_flux)? MODEL_BACK : MODEL_NONE)
+	|(FLAG(obj2.prof_dirac_flux)? MODEL_DIRAC : MODEL_NONE)
+	|(FLAG(obj2.prof_spheroid_flux)?
+		(FLAG(obj2.prof_spheroid_sersicn)?
+			MODEL_SERSIC : MODEL_DEVAUCOULEURS) : MODEL_NONE)
+	|(FLAG(obj2.prof_disk_flux)? MODEL_EXPONENTIAL : MODEL_NONE)
+	|(FLAG(obj2.prof_bar_flux)? MODEL_BAR : MODEL_NONE)
+	|(FLAG(obj2.prof_arms_flux)? MODEL_ARMS : MODEL_NONE);
+    theprofit = profit_init(thepsf, modeltype);
+    changecatparamarrays("VECTOR_MODEL", &theprofit->nparam, 1);
+    changecatparamarrays("VECTOR_MODELERR", &theprofit->nparam, 1);
+    nparam2[0] = nparam2[1] = theprofit->nparam;
+    changecatparamarrays("MATRIX_MODELERR", nparam2, 2);
+    if (prefs.dprof_flag)
+      thedprofit = profit_init(thedpsf, modeltype);
     if (prefs.pattern_flag)
       {
-      npat = prefs.prof_disk_patternvectorsize;
-      if (npat<prefs.prof_disk_patternmodvectorsize)
-        npat = prefs.prof_disk_patternmodvectorsize;
-      if (npat<prefs.prof_disk_patternargvectorsize)
-        npat = prefs.prof_disk_patternargvectorsize;
+      npat0 = prefs.prof_disk_patternvectorsize;
+      if (npat0<prefs.prof_disk_patternmodvectorsize)
+        npat0 = prefs.prof_disk_patternmodvectorsize;
+      if (npat0<prefs.prof_disk_patternargvectorsize)
+        npat0 = prefs.prof_disk_patternargvectorsize;
 /*---- Do a copy of the original number of pattern components */
-      prefs.prof_disk_patternncomp = npat;
-      pattern = pattern_init(theprofit, prefs.pattern_type, npat);
+      prefs.prof_disk_patternncomp = npat0;
+      pattern = pattern_init(theprofit, prefs.pattern_type, npat0);
       if (FLAG(obj2.prof_disk_patternvector))
         {
         npat = pattern->size[2];
@@ -144,9 +204,19 @@ void	makeit()
       {
       if (i)
         QPRINTF(OUTPUT, "+");
-      QPRINTF(OUTPUT, "%s", profname[theprofit->prof[i]->code]);
+      QPRINTF(OUTPUT, "%s", theprofit->prof[i]->name);
       }
     QPRINTF(OUTPUT, "\n");
+    if (FLAG(obj2.prof_concentration)|FLAG(obj2.prof_concentration))
+      {
+      thepprofit = profit_init(thepsf, MODEL_DIRAC);
+      theqprofit = profit_init(thepsf, MODEL_EXPONENTIAL);
+      }
+#else
+    error(EXIT_FAILURE,
+		"*Error*: model-fitting is not supported in this build.\n",
+			" Please check your configure options");
+#endif
     }
 
   if (prefs.filter_flag)
@@ -186,15 +256,6 @@ void	makeit()
   alloccatparams();
   useprefs();
 
-/* Check if a specific extension should be loaded */
-  if ((nima0=selectext(prefs.image_name[0])) != RETURN_ERROR)
-    {
-    forcextflag = 1;
-    ntabmax = next = 1;
-    }
-  else
-    forcextflag = 0;
-
   if (!(imacat = read_cat(prefs.image_name[0])))
     error(EXIT_FAILURE, "*Error*: cannot open ", prefs.image_name[0]);
   close_cat(imacat);
@@ -216,13 +277,6 @@ void	makeit()
       }
     }
 
-/* Do the same for other data (but do not force single extension mode) */
-  nima1 = selectext(prefs.image_name[1]);
-  nweight0 = selectext(prefs.wimage_name[0]);
-  nweight1 = selectext(prefs.wimage_name[1]);
-  for (i=0; i<prefs.nfimage_name; i++)
-    nflag[i] = selectext(prefs.fimage_name[i]);
-
   thecat.next = next;
 
 /*-- Init the CHECK-images */
@@ -250,7 +304,7 @@ void	makeit()
     init_xml(next);
 
 /* Go through all images */
-  nok = -1;
+  nok = 0;
   for (ntab = 0 ; ntab<ntabmax; ntab++, imatab = imatab->nexttab)
     {
 /*--  Check for the next valid image extension */
@@ -258,11 +312,12 @@ void	makeit()
 	|| !strncmp(imatab->xtension, "BINTABLE", 8)
 	|| !strncmp(imatab->xtension, "ASCTABLE", 8)))
       continue;
+
     nok++;
 
 /*-- Initial time measurement*/
     time(&thetime1);
-    thecat.currext = nok+1;
+    thecat.currext = nok;
 
     dfield = field = wfield = dwfield = NULL;
 
@@ -270,9 +325,9 @@ void	makeit()
       {
 /*---- Init the Detection and Measurement-images */
       dfield = newfield(prefs.image_name[0], DETECT_FIELD,
-	nima0<0? nok:nima0);
+	nima0<0? ntab:nima0);
       field = newfield(prefs.image_name[1], MEASURE_FIELD,
-	nima1<0? nok:nima1);
+	nima1<0? ntab:nima1);
       if ((field->width!=dfield->width) || (field->height!=dfield->height))
         error(EXIT_FAILURE, "*Error*: Frames have different sizes","");
 /*---- Prepare interpolation */
@@ -284,9 +339,9 @@ void	makeit()
     else
       {
       field = newfield(prefs.image_name[0], DETECT_FIELD | MEASURE_FIELD,
-		nima0<0? nok:nima0);
+		nima0<0? ntab:nima0);
 
-/*-- Prepare interpolation */
+/*---- Prepare interpolation */
       if ((prefs.dweight_flag || prefs.weight_flag)
 	&& prefs.interp_type[0] == INTERP_ALL)
       init_interpolate(field, -1, -1);       /* 0.0 or anything else */
@@ -305,7 +360,8 @@ void	makeit()
           {
 /*-------- First: the "measurement" weights */
           wfield = newweight(prefs.wimage_name[1],field,prefs.weight_type[1],
-		nweight1<0? nok:nweight1);
+		(nima1<0 && prefs.image_name[1])?
+			ntab : (nweight1<0?1:nweight1));
           wtype = prefs.weight_type[1];
           interpthresh = prefs.weight_thresh[1];
 /*-------- Convert the interpolation threshold to variance units */
@@ -322,13 +378,13 @@ void	makeit()
           if (prefs.weight_type[0] == WEIGHT_FROMINTERP)
             {
             dwfield=newweight(prefs.wimage_name[0],wfield,prefs.weight_type[0],
-		nweight0<0? nok:nweight0);
+		nima0<0? ntab : (nweight0<0? 1 :nweight0));
             weight_to_var(wfield, &interpthresh, 1);
             }
           else
             {
             dwfield = newweight(prefs.wimage_name[0], dfield?dfield:field,
-		prefs.weight_type[0], nweight0<0? nok:nweight0);
+		prefs.weight_type[0], nima0<0? ntab : (nweight0<0?1:nweight0));
             weight_to_var(dwfield, &interpthresh, 1);
             }
           dwfield->weight_thresh = interpthresh;
@@ -341,7 +397,7 @@ void	makeit()
         {
 /*------ Single-weight-map mode */
         wfield = newweight(prefs.wimage_name[0], dfield?dfield:field,
-			prefs.weight_type[0], nweight0<0? nok:nweight0);
+		prefs.weight_type[0], nima0<0? ntab : (nweight0<0?1:nweight0));
         wtype = prefs.weight_type[0];
         interpthresh = prefs.weight_thresh[0];
 /*------ Convert the interpolation threshold to variance units */
@@ -357,7 +413,7 @@ void	makeit()
     for (i=0; i<prefs.nimaflag; i++)
       {
       pffield[i] = newfield(prefs.fimage_name[i], FLAG_FIELD,
-		nflag[i]<0? nok:nflag[i]);
+		nima0<0? ntab : (nflag[i]<0?1:nflag[i]));
       if ((pffield[i]->width!=field->width)
 	|| (pffield[i]->height!=field->height))
         error(EXIT_FAILURE,
@@ -367,7 +423,7 @@ void	makeit()
 /*-- Compute background maps for `standard' fields */
     QPRINTF(OUTPUT, dfield? "Measurement image:"
 			: "Detection+Measurement image: ");
-    makeback(field, wfield);
+    makeback(field, wfield, prefs.wscale_flag[1]);
     QPRINTF(OUTPUT, (dfield || (dwfield&&dwfield->flags^INTERP_FIELD))? "(M)   "
 		"Background: %-10g RMS: %-10g / Threshold: %-10g \n"
 		: "(M+D) "
@@ -375,17 +431,18 @@ void	makeit()
 	field->backmean, field->backsig, (field->flags & DETECT_FIELD)?
 	field->dthresh: field->thresh);
     if (dfield)
-    {
+      {
       QPRINTF(OUTPUT, "Detection image: ");
       makeback(dfield, dwfield? dwfield
-			: (prefs.weight_type[0] == WEIGHT_NONE?NULL:wfield));
+			: (prefs.weight_type[0] == WEIGHT_NONE?NULL:wfield),
+		prefs.wscale_flag[0]);
       QPRINTF(OUTPUT, "(D)   "
 		"Background: %-10g RMS: %-10g / Threshold: %-10g \n",
 	dfield->backmean, dfield->backsig, dfield->dthresh);
       }
     else if (dwfield && dwfield->flags^INTERP_FIELD)
       {
-      makeback(field, dwfield);
+      makeback(field, dwfield, prefs.wscale_flag[0]);
       QPRINTF(OUTPUT, "(D)   "
 		"Background: %-10g RMS: %-10g / Threshold: %-10g \n",
 	field->backmean, field->backsig, field->dthresh);
@@ -407,15 +464,59 @@ void	makeit()
         if ((check=prefs.check[i]))
           reinitcheck(field, check);
 
+    if (!forcextflag && nok>1)
+      {
+      if (prefs.psf_flag)
+        {
+/*------ Read other PSF extensions */
+        NFPRINTF(OUTPUT, "Reading PSF information");
+        psf_end(thepsf, thepsfit);
+        if (prefs.dpsf_flag)
+          {
+          psf_end(thedpsf, thedpsfit);
+          thedpsf = psf_load(prefs.psf_name[0], nok);
+          thepsf = psf_load(prefs.psf_name[1], nok);
+          }
+        else
+          thepsf = psf_load(prefs.psf_name[0], nok); 
+        }
+
+#ifdef USE_MODEL
+      if (prefs.prof_flag)
+        {
+/*------ Create profiles at full resolution */
+        profit_end(theprofit);
+        theprofit = profit_init(thepsf, modeltype);
+        if (prefs.dprof_flag)
+          {
+          profit_end(thedprofit);
+          thedprofit = profit_init(thedpsf, modeltype);
+          }
+        if (prefs.pattern_flag)
+          {
+          pattern = pattern_init(theprofit, prefs.pattern_type, npat0);
+          pattern_end(pattern);
+          }
+        if (FLAG(obj2.prof_concentration)|FLAG(obj2.prof_concentration))
+          {
+          profit_end(thepprofit);
+          profit_end(theqprofit);
+          thepprofit = profit_init(thepsf, MODEL_DIRAC);
+          theqprofit = profit_init(thepsf, MODEL_EXPONENTIAL);
+          }
+        }
+#endif
+      }
+
 /*-- Initialize PSF contexts and workspace */
     if (prefs.psf_flag)
       {
       psf_readcontext(thepsf, field);
-      psf_init(thepsf);
+      psf_init();
       if (prefs.dpsf_flag)
         {
         psf_readcontext(thepsf, dfield);
-        psf_init(thepsf); /*?*/
+        psf_init();
         }
       }
 
@@ -461,8 +562,8 @@ void	makeit()
     reendcat();
 
 /* Update XML data */
-  if (prefs.xml_flag || prefs.cat_type==ASCII_VO)
-    update_xml(&thecat, dfield? dfield:field, field,
+    if (prefs.xml_flag || prefs.cat_type==ASCII_VO)
+      update_xml(&thecat, dfield? dfield:field, field,
 	dwfield? dwfield:wfield, wfield);
 
 
@@ -479,11 +580,11 @@ void	makeit()
     if (dwfield)
       endfield(dwfield);
 
-    QPRINTF(OUTPUT, "Objects: detected %-8d / sextracted %-8d               \n",
+    QPRINTF(OUTPUT, "      Objects: detected %-8d / sextracted %-8d        \n\n",
 	thecat.ndetect, thecat.ntotal);
     }
 
-  if (nok<0)
+  if (nok<=0)
     error(EXIT_FAILURE, "Not enough valid FITS image extensions in ",
 	prefs.image_name[0]);
   free_cat(&imacat, 1);
@@ -508,17 +609,26 @@ void	makeit()
   if (prefs.growth_flag)
     endgrowth();
 
+#ifdef USE_MODEL
   if (prefs.prof_flag)
     {
     profit_end(theprofit);
+    if (prefs.dprof_flag)
+      profit_end(thedprofit);
+    if (FLAG(obj2.prof_concentration)|FLAG(obj2.prof_concentration))
+      {
+      profit_end(thepprofit);
+      profit_end(theqprofit);
+      }
     fft_end();
     }
+#endif
 
-  if (prefs.psf_flag || prefs.prof_flag)
-    psf_end(thepsf,thepsfit); /*?*/
+  if (prefs.psf_flag)
+    psf_end(thepsf, thepsfit);
 
   if (prefs.dpsf_flag)
-    psf_end(ppsf,ppsfit);
+    psf_end(thedpsf, thedpsfit);
 
   if (FLAG(obj2.sprob))
     neurclose();
@@ -530,7 +640,7 @@ void	makeit()
 	tm->tm_year+1900, tm->tm_mon+1, tm->tm_mday);
   sprintf(prefs.stime_end,"%02d:%02d:%02d",
 	tm->tm_hour, tm->tm_min, tm->tm_sec);
-  prefs.time_diff = difftime(thetimet2, thetimet);
+  prefs.time_diff = counter_seconds() - dtime;
 
 /* Write XML */
   if (prefs.xml_flag)
@@ -618,3 +728,4 @@ void	write_error(char *msg1, char *msg2)
   return;
   }
 
+
