@@ -1,18 +1,30 @@
 /*
- 				param.h
-
-*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+*				param.h
 *
-*	Part of:	SExtractor
+* List of regular measurement parameters.
 *
-*	Author:		E.BERTIN (IAP)
+*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 *
-*	Contents:	parameter list for catalog data.
+*	This file part of:	SExtractor
 *
-*	Last modify:	08/04/2009
+*	Copyright:		(C) 1993-2014 Emmanuel Bertin -- IAP/CNRS/UPMC
 *
-*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-*/
+*	License:		GNU General Public License
+*
+*	SExtractor is free software: you can redistribute it and/or modify
+*	it under the terms of the GNU General Public License as published by
+*	the Free Software Foundation, either version 3 of the License, or
+*	(at your option) any later version.
+*	SExtractor is distributed in the hope that it will be useful,
+*	but WITHOUT ANY WARRANTY; without even the implied warranty of
+*	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+*	GNU General Public License for more details.
+*	You should have received a copy of the GNU General Public License
+*	along with SExtractor. If not, see <http://www.gnu.org/licenses/>.
+*
+*	Last modified:		17/02/2014
+*
+*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%*/
 
 objstruct	outobj;
 obj2struct	outobj2;
@@ -115,6 +127,9 @@ keystruct	objkey[] = {
   {"MAGERR_WIN", "RMS error for MAG_WIN",
 	&outobj2.magerr_win, H_FLOAT, T_FLOAT, "%8.4f", "mag",
 	"stat.stdev;phot.mag", "mag"},
+  {"SNR_WIN", "Gaussian-weighted SNR",
+	&outobj2.snr_win, H_FLOAT, T_FLOAT, "%10.4g", "",
+	"stat.snr", ""},
 
   {"FLUX_SOMFIT", "Flux derived from SOM fit",
 	&outobj2.flux_somfit, H_FLOAT, T_FLOAT, "%12.7g", "count",
@@ -153,7 +168,7 @@ keystruct	objkey[] = {
 	&outobj2.stderr_galfit, H_FLOAT, T_FLOAT, "%10g", ""},
 
   {"GALDANG_IMAGE", "Galaxy disk position angle  from the galaxy fit",
-	&outobj2.gdposang, H_FLOAT, T_FLOAT, "%5.1f", "deg",
+	&outobj2.gdposang, H_FLOAT, T_FLOAT, "%6.2f", "deg",
 	"pos.posAng;stat.fit.param", "deg"},
   {"GALDSCALE_IMAGE", "Galaxy disk-scale from the galaxy fit",
 	&outobj2.gdscale, H_FLOAT, T_FLOAT, "%9.3f", "pixel",
@@ -171,7 +186,7 @@ keystruct	objkey[] = {
 	&outobj2.gbratio, H_FLOAT, T_FLOAT, "%5.3f", "",
 	"src.morph.param;stat.fit.param", ""},
   {"GALBANG_IMAGE", "Galaxy bulge position angle  from the galaxy fit",
-	&outobj2.gbposang, H_FLOAT, T_FLOAT, "%5.1f", "deg",
+	&outobj2.gbposang, H_FLOAT, T_FLOAT, "%6.2f", "deg",
 	"pos.posAng;stat.fit.param", "deg"},
   {"GALBSCALE_IMAGE", "Galaxy bulge-scale from the galaxy fit",
 	&outobj2.gbscale, H_FLOAT, T_FLOAT, "%9.3f", "pixel",
@@ -222,11 +237,17 @@ keystruct	objkey[] = {
   {"YPEAK_IMAGE", "y-coordinate of the brightest pixel",
 	&outobj.peaky, H_INT, T_LONG, "%10d", "pixel",
 	"pos.cartesian.y", "pix"},
+  {"XPEAK_FOCAL", "Focal-plane x coordinate of the brightest pixel",
+	&outobj2.peakxf, H_FLOAT, T_DOUBLE, "%18.10e", "",
+	"pos.cartesian.x", ""},
+  {"YPEAK_FOCAL", "Focal-plane y coordinate of the brightest pixel",
+	&outobj2.peakyf, H_FLOAT, T_DOUBLE, "%18.10e", "",
+	"pos.cartesian.y", ""},
   {"XPEAK_WORLD", "World-x coordinate of the brightest pixel",
-	&outobj2.peakxw, H_FLOAT, T_DOUBLE, "%15.10e", "deg",
+	&outobj2.peakxw, H_FLOAT, T_DOUBLE, "%18.10e", "deg",
 	"pos.eq.ra", "deg"},
   {"YPEAK_WORLD", "World-y coordinate of the brightest pixel",
-	&outobj2.peakyw, H_FLOAT, T_DOUBLE, "%15.10e", "deg",
+	&outobj2.peakyw, H_FLOAT, T_DOUBLE, "%18.10e", "deg",
 	"pos.eq.dec", "deg"},
 
   {"ALPHAPEAK_SKY", "Right ascension of brightest pix (native)",
@@ -251,22 +272,28 @@ keystruct	objkey[] = {
 	"pos.eq.dec", "deg"},
 
   {"X_IMAGE", "Object position along x",
-	&outobj2.sposx, H_FLOAT, T_FLOAT, "%10.3f", "pixel",
+	&outobj2.sposx, H_FLOAT, T_FLOAT, "%11.4f", "pixel",
 	"pos.cartesian.x;pos.barycenter;instr.det;meta.main", "pix"},
   {"Y_IMAGE", "Object position along y",
-	&outobj2.sposy, H_FLOAT, T_FLOAT, "%10.3f", "pixel",
+	&outobj2.sposy, H_FLOAT, T_FLOAT, "%11.4f", "pixel",
 	"pos.cartesian.y;pos.barycenter;instr.det;meta.main", "pix"},
   {"X_IMAGE_DBL", "Object position along x (double precision)",
-	&outobj2.posx, H_FLOAT, T_DOUBLE, "%10.3f", "pixel",
+	&outobj2.posx, H_FLOAT, T_DOUBLE, "%11.4f", "pixel",
 	"pos.cartesian.x;pos.barycenter;instr.det", "pix"},
   {"Y_IMAGE_DBL", "Object position along y (double precision)",
-	&outobj2.posy, H_FLOAT, T_DOUBLE, "%10.3f", "pixel",
+	&outobj2.posy, H_FLOAT, T_DOUBLE, "%11.4f", "pixel",
 	"pos.cartesian.x;pos.barycenter;instr.det", "pix"},
+  {"X_FOCAL", "Barycenter position along focal-plane x axis",
+	&outobj2.mxf, H_FLOAT, T_DOUBLE, "%18.10e", "",
+	"pos.cartesian.x", ""},
+  {"Y_FOCAL", "Barycenter position along focal-plane y axis",
+	&outobj2.myf, H_FLOAT, T_DOUBLE, "%18.10e", "",
+	"pos.cartesian.y", ""},
   {"X_WORLD", "Barycenter position along world x axis",
-	&outobj2.mxw, H_FLOAT, T_DOUBLE, "%15.10e", "deg",
+	&outobj2.mxw, H_FLOAT, T_DOUBLE, "%18.10e", "deg",
 	"pos.eq.ra", "deg"},
   {"Y_WORLD", "Barycenter position along world y axis",
-	&outobj2.myw, H_FLOAT, T_DOUBLE, "%15.10e", "deg",
+	&outobj2.myw, H_FLOAT, T_DOUBLE, "%18.10e", "deg",
 	"pos.eq.dec", "deg"},
   {"X_MAMA", "Barycenter position along MAMA x axis",
 	&outobj2.mamaposx, H_FLOAT, T_DOUBLE, "%8.1f", "m**(-6)",
@@ -297,41 +324,41 @@ keystruct	objkey[] = {
 	"pos.eq.dec;pos.barycenter", "deg"},
 
   {"X2_IMAGE", "Variance along x",
-	&outobj.mx2, H_EXPO, T_DOUBLE, "%15.10e", "pixel**2",
+	&outobj.mx2, H_EXPO, T_DOUBLE, "%18.10e", "pixel**2",
 	"src.impactParam;instr.det", "pix2"},
   {"Y2_IMAGE", "Variance along y",
-	&outobj.my2, H_EXPO, T_DOUBLE, "%15.10e", "pixel**2",
+	&outobj.my2, H_EXPO, T_DOUBLE, "%18.10e", "pixel**2",
 	"src.impactParam;instr.det", "pix2"},
   {"XY_IMAGE", "Covariance between x and y",
-	&outobj.mxy, H_EXPO, T_DOUBLE, "%15.10e", "pixel**2",
+	&outobj.mxy, H_EXPO, T_DOUBLE, "%18.10e", "pixel**2",
 	"src.impactParam;instr.det", "pix2"},
   {"X2_WORLD", "Variance along X-WORLD (alpha)",
-	&outobj2.mx2w, H_EXPO, T_DOUBLE, "%15.10e", "deg**2",
+	&outobj2.mx2w, H_EXPO, T_DOUBLE, "%18.10e", "deg**2",
 	"src.impactParam", "deg2"},
   {"Y2_WORLD", "Variance along Y-WORLD (delta)",
-	&outobj2.my2w, H_EXPO, T_DOUBLE, "%15.10e", "deg**2",
+	&outobj2.my2w, H_EXPO, T_DOUBLE, "%18.10e", "deg**2",
 	"src.impactParam", "deg2"},
   {"XY_WORLD", "Covariance between X-WORLD and Y-WORLD",
-	&outobj2.mxyw, H_EXPO, T_DOUBLE, "%15.10e", "deg**2",
+	&outobj2.mxyw, H_EXPO, T_DOUBLE, "%18.10e", "deg**2",
 	"src.impactParam", "deg2"},
 
   {"CXX_IMAGE", "Cxx object ellipse parameter",
-	&outobj.cxx, H_EXPO, T_FLOAT, "%12.7e", "pixel**(-2)",
+	&outobj.cxx, H_EXPO, T_FLOAT, "%15.7e", "pixel**(-2)",
 	"src.impactParam;instr.det", "pix-2"},
   {"CYY_IMAGE", "Cyy object ellipse parameter",
-	&outobj.cyy, H_EXPO, T_FLOAT, "%12.7e", "pixel**(-2)",
+	&outobj.cyy, H_EXPO, T_FLOAT, "%15.7e", "pixel**(-2)",
 	"src.impactParam;instr.det", "pix-2"},
   {"CXY_IMAGE", "Cxy object ellipse parameter",
-	&outobj.cxy, H_EXPO, T_FLOAT, "%12.7e", "pixel**(-2)",
+	&outobj.cxy, H_EXPO, T_FLOAT, "%15.7e", "pixel**(-2)",
 	"src.impactParam;instr.det", "pix-2"},
   {"CXX_WORLD", "Cxx object ellipse parameter (WORLD units)",
-	&outobj2.cxxw, H_EXPO, T_FLOAT, "%12.7e", "deg**(-2)",
+	&outobj2.cxxw, H_EXPO, T_FLOAT, "%15.7e", "deg**(-2)",
 	"src.impactParam", "deg-2"},
   {"CYY_WORLD", "Cyy object ellipse parameter (WORLD units)",
-	&outobj2.cyyw, H_EXPO, T_FLOAT, "%12.7e", "deg**(-2)",
+	&outobj2.cyyw, H_EXPO, T_FLOAT, "%15.7e", "deg**(-2)",
 	"src.impactParam", "deg-2"},
   {"CXY_WORLD", "Cxy object ellipse parameter (WORLD units)",
-	&outobj2.cxyw, H_EXPO, T_FLOAT, "%12.7e", "deg**(-2)",
+	&outobj2.cxyw, H_EXPO, T_FLOAT, "%15.7e", "deg**(-2)",
 	"src.impactParam", "deg-2"},
 
   {"A_IMAGE", "Profile RMS along major axis",
@@ -341,7 +368,7 @@ keystruct	objkey[] = {
 	&outobj.b, H_FLOAT, T_FLOAT, "%9.3f", "pixel",
 	"phys.size.sminAxis;instr.det;meta.main", "pix"},
   {"THETA_IMAGE", "Position angle (CCW/x)",
-	&outobj.theta, H_FLOAT, T_FLOAT, "%5.1f", "deg",
+	&outobj.theta, H_FLOAT, T_FLOAT, "%6.2f", "deg",
 	"pos.posAng;instr.det;meta.main", "deg"},
   {"A_WORLD", "Profile RMS along major axis (world units)",
 	&outobj2.aw, H_FLOAT, T_FLOAT, "%12.7g", "deg",
@@ -350,7 +377,7 @@ keystruct	objkey[] = {
 	&outobj2.bw, H_FLOAT, T_FLOAT, "%12.7g", "deg",
 	"phys.size.sminAxis;meta.main", "deg"},
   {"THETA_WORLD", "Position angle (CCW/world-x)",
-	&outobj2.thetaw, H_FLOAT, T_FLOAT, "%5.1f", "deg",
+	&outobj2.thetaw, H_FLOAT, T_FLOAT, "%6.2f", "deg",
 	"pos.posAng", "deg"},
   {"THETA_SKY", "Position angle (east of north) (native)",
 	&outobj2.thetas, H_FLOAT, T_FLOAT, "%+6.2f", "deg",
@@ -363,22 +390,22 @@ keystruct	objkey[] = {
 	"pos.posAng", "deg"},
 
   {"ERRX2_IMAGE", "Variance of position along x",
-	&outobj.poserr_mx2, H_EXPO, T_DOUBLE, "%15.10e", "pixel**2",
+	&outobj.poserr_mx2, H_EXPO, T_DOUBLE, "%18.10e", "pixel**2",
 	"stat.variance;pos.errorEllipse;instr.det", "pix2"},
   {"ERRY2_IMAGE", "Variance of position along y",
-	&outobj.poserr_my2, H_EXPO, T_DOUBLE, "%15.10e", "pixel**2",
+	&outobj.poserr_my2, H_EXPO, T_DOUBLE, "%18.10e", "pixel**2",
 	"stat.variance;pos.errorEllipse;instr.det", "pix2"},
   {"ERRXY_IMAGE", "Covariance of position between x and y",
-	&outobj.poserr_mxy, H_EXPO, T_DOUBLE, "%15.10e", "pixel**2",
+	&outobj.poserr_mxy, H_EXPO, T_DOUBLE, "%18.10e", "pixel**2",
 	"stat.covariance;pos.errorEllipse;instr.det", "pix2"},
   {"ERRX2_WORLD", "Variance of position along X-WORLD (alpha)",
-	&outobj2.poserr_mx2w, H_EXPO, T_DOUBLE, "%15.10e", "deg**2",
+	&outobj2.poserr_mx2w, H_EXPO, T_DOUBLE, "%18.10e", "deg**2",
 	"stat.variance;pos.errorEllipse", "deg2"},
   {"ERRY2_WORLD", "Variance of position along Y-WORLD (delta)",
-	&outobj2.poserr_my2w, H_EXPO, T_DOUBLE, "%15.10e", "deg**2",
+	&outobj2.poserr_my2w, H_EXPO, T_DOUBLE, "%18.10e", "deg**2",
 	"stat.variance;pos.errorEllipse", "deg2"},
   {"ERRXY_WORLD", "Covariance of position X-WORLD/Y-WORLD",
-	&outobj2.poserr_mxyw, H_EXPO, T_DOUBLE, "%15.10e", "deg**2",
+	&outobj2.poserr_mxyw, H_EXPO, T_DOUBLE, "%18.10e", "deg**2",
 	"stat.covariance;pos.errorEllipse", "deg2"},
 
   {"ERRCXX_IMAGE", "Cxx error ellipse parameter",
@@ -401,13 +428,13 @@ keystruct	objkey[] = {
 	"src.impactParam;pos.errorEllipse", "deg-2"},
 
   {"ERRA_IMAGE", "RMS position error along major axis",
-	&outobj2.poserr_a, H_FLOAT, T_FLOAT, "%8.4f", "pixel",
+	&outobj2.poserr_a, H_FLOAT, T_FLOAT, "%9.5f", "pixel",
 	"stat.stdev;stat.max;pos.errorEllipse;instr.det;meta.main", "pix"},
   {"ERRB_IMAGE", "RMS position error along minor axis",
-	&outobj2.poserr_b, H_FLOAT, T_FLOAT, "%8.4f", "pixel",
+	&outobj2.poserr_b, H_FLOAT, T_FLOAT, "%9.5f", "pixel",
 	"stat.stdev;stat.min;pos.errorEllipse;instr.det;meta.main", "pix"},
   {"ERRTHETA_IMAGE", "Error ellipse position angle (CCW/x)",
-	&outobj2.poserr_theta, H_FLOAT, T_FLOAT, "%5.1f", "deg",
+	&outobj2.poserr_theta, H_FLOAT, T_FLOAT, "%6.2f", "deg",
 	"pos.posAng;pos.errorEllipse;instr.det;meta.main", "deg"},
   {"ERRA_WORLD", "World RMS position error along major axis",
 	&outobj2.poserr_aw, H_FLOAT, T_FLOAT, "%12.7g", "deg",
@@ -416,30 +443,37 @@ keystruct	objkey[] = {
 	&outobj2.poserr_bw, H_FLOAT, T_FLOAT, "%12.7g", "deg",
 	"stat.stdev;stat.min;pos.errorEllipse;meta.main", "deg"},
   {"ERRTHETA_WORLD", "Error ellipse pos. angle (CCW/world-x)",
-	&outobj2.poserr_thetaw, H_FLOAT, T_FLOAT, "%5.1f", "deg",
+	&outobj2.poserr_thetaw, H_FLOAT, T_FLOAT, "%6.2f", "deg",
 	"pos.posAng;pos.errorEllipse", "deg"},
   {"ERRTHETA_SKY", "Native error ellipse pos. angle (east of north)",
-	&outobj2.poserr_thetas, H_FLOAT, T_FLOAT, "%5.1f", "deg",
+	&outobj2.poserr_thetas, H_FLOAT, T_FLOAT, "%6.2f", "deg",
 	"pos.posAng;pos.errorEllipse", "deg"},
   {"ERRTHETA_J2000", "J2000 error ellipse pos. angle (east of north)",
-	&outobj2.poserr_theta2000, H_FLOAT, T_FLOAT, "%5.1f", "deg",
+	&outobj2.poserr_theta2000, H_FLOAT, T_FLOAT, "%6.2f", "deg",
 	"pos.posAng;pos.errorEllipse;meta.main", "deg"},
   {"ERRTHETA_B1950", "B1950 error ellipse pos. angle (east of north)",
-	&outobj2.poserr_theta1950, H_FLOAT, T_FLOAT, "%5.1f", "deg",
+	&outobj2.poserr_theta1950, H_FLOAT, T_FLOAT, "%6.2f", "deg",
 	"pos.posAng;pos.errorEllipse", "deg"},
 
   {"XWIN_IMAGE", "Windowed position estimate along x",
-	&outobj2.winpos_x, H_FLOAT, T_DOUBLE, "%10.3f", "pixel",
+	&outobj2.winpos_x, H_FLOAT, T_DOUBLE, "%11.4f", "pixel",
 	"pos.cartesian.x;instr.det", "pix"},
   {"YWIN_IMAGE", "Windowed position estimate along y",
-	&outobj2.winpos_y, H_FLOAT, T_DOUBLE, "%10.3f", "pixel",
+	&outobj2.winpos_y, H_FLOAT, T_DOUBLE, "%11.4f", "pixel",
 	"pos.cartesian.y;instr.det", "pix"},
 
+  {"XWIN_FOCAL", "Windowed position along focal-plane x axis",
+	&outobj2.winpos_xf, H_FLOAT, T_DOUBLE, "%18.10e", "",
+	"pos.cartesian.x", ""},
+  {"YWIN_FOCAL", "Windowed position along focal-plane y axis",
+	&outobj2.winpos_yf, H_FLOAT, T_DOUBLE, "%18.10e", "",
+	"pos.cartesian.y", ""},
+
   {"XWIN_WORLD", "Windowed position along world x axis",
-	&outobj2.winpos_xw, H_FLOAT, T_DOUBLE, "%15.10e", "deg",
+	&outobj2.winpos_xw, H_FLOAT, T_DOUBLE, "%18.10e", "deg",
 	"pos.eq.ra", "deg"},
   {"YWIN_WORLD", "Windowed position along world y axis",
-	&outobj2.winpos_yw, H_FLOAT, T_DOUBLE, "%15.10e", "deg",
+	&outobj2.winpos_yw, H_FLOAT, T_DOUBLE, "%18.10e", "deg",
 	"pos.eq.dec", "deg"},
 
   {"ALPHAWIN_SKY", "Windowed right ascension  (native)",
@@ -464,41 +498,41 @@ keystruct	objkey[] = {
 	"pos.eq.dec", "deg"},
 
   {"X2WIN_IMAGE", "Windowed variance along x",
-	&outobj2.win_mx2, H_EXPO, T_DOUBLE, "%15.10e", "pixel**2",
+	&outobj2.win_mx2, H_EXPO, T_DOUBLE, "%18.10e", "pixel**2",
  	"src.impactParam;instr.det", "pix2"},
   {"Y2WIN_IMAGE", "Windowed variance along y",
-	&outobj2.win_my2, H_EXPO, T_DOUBLE, "%15.10e", "pixel**2",
+	&outobj2.win_my2, H_EXPO, T_DOUBLE, "%18.10e", "pixel**2",
 	"src.impactParam;instr.det", "pix2"},
   {"XYWIN_IMAGE", "Windowed covariance between x and y",
-	&outobj2.win_mxy, H_EXPO, T_DOUBLE, "%15.10e", "pixel**2",
+	&outobj2.win_mxy, H_EXPO, T_DOUBLE, "%18.10e", "pixel**2",
 	"src.impactParam;instr.det", "pix2"},
   {"X2WIN_WORLD", "Windowed variance along X-WORLD (alpha)",
-	&outobj2.win_mx2w, H_EXPO, T_DOUBLE, "%15.10e", "deg**2",
+	&outobj2.win_mx2w, H_EXPO, T_DOUBLE, "%18.10e", "deg**2",
 	"src.impactParam", "deg2"},
   {"Y2WIN_WORLD", "Windowed variance along Y-WORLD (delta)",
-	&outobj2.win_my2w, H_EXPO, T_DOUBLE, "%15.10e", "deg**2",
+	&outobj2.win_my2w, H_EXPO, T_DOUBLE, "%18.10e", "deg**2",
 	"src.impactParam", "deg2"},
   {"XYWIN_WORLD", "Windowed covariance between X-WORLD and Y-WORLD",
-	&outobj2.win_mxyw, H_EXPO, T_DOUBLE, "%15.10e", "deg**2",
+	&outobj2.win_mxyw, H_EXPO, T_DOUBLE, "%18.10e", "deg**2",
 	"src.impactParam", "deg2"},
 
   {"CXXWIN_IMAGE", "Windowed Cxx object ellipse parameter",
-	&outobj2.win_cxx, H_EXPO, T_FLOAT, "%12.7e", "pixel**(-2)",
+	&outobj2.win_cxx, H_EXPO, T_FLOAT, "%15.7e", "pixel**(-2)",
 	"src.impactParam;instr.det", "pix-2"},
   {"CYYWIN_IMAGE", "Windowed Cyy object ellipse parameter",
-	&outobj2.win_cyy, H_EXPO, T_FLOAT, "%12.7e", "pixel**(-2)",
+	&outobj2.win_cyy, H_EXPO, T_FLOAT, "%15.7e", "pixel**(-2)",
 	"src.impactParam;instr.det", "pix-2"},
   {"CXYWIN_IMAGE", "Windowed Cxy object ellipse parameter",
-	&outobj2.win_cxy, H_EXPO, T_FLOAT, "%12.7e", "pixel**(-2)",
+	&outobj2.win_cxy, H_EXPO, T_FLOAT, "%15.7e", "pixel**(-2)",
 	"src.impactParam;instr.det", "pix-2"},
   {"CXXWIN_WORLD", "Windowed Cxx object ellipse parameter (WORLD units)",
-	&outobj2.win_cxxw, H_EXPO, T_FLOAT, "%12.7e", "deg**(-2)",
+	&outobj2.win_cxxw, H_EXPO, T_FLOAT, "%15.7e", "deg**(-2)",
 	"src.impactParam", "deg-2"},
   {"CYYWIN_WORLD", "Windowed Cyy object ellipse parameter (WORLD units)",
-	&outobj2.win_cyyw, H_EXPO, T_FLOAT, "%12.7e", "deg**(-2)",
+	&outobj2.win_cyyw, H_EXPO, T_FLOAT, "%15.7e", "deg**(-2)",
 	"src.impactParam", "deg-2"},
   {"CXYWIN_WORLD", "Windowed Cxy object ellipse parameter (WORLD units)",
-	&outobj2.win_cxyw, H_EXPO, T_FLOAT, "%12.7e", "deg**(-2)",
+	&outobj2.win_cxyw, H_EXPO, T_FLOAT, "%15.7e", "deg**(-2)",
 	"src.impactParam", "deg-2"},
 
   {"AWIN_IMAGE", "Windowed profile RMS along major axis",
@@ -508,7 +542,7 @@ keystruct	objkey[] = {
 	&outobj2.win_b, H_FLOAT, T_FLOAT, "%9.3f", "pixel",
 	"phys.size.sminAxis;instr.det", "pix"},
   {"THETAWIN_IMAGE", "Windowed position angle (CCW/x)",
-	&outobj2.win_theta, H_FLOAT, T_FLOAT, "%5.1f", "deg",
+	&outobj2.win_theta, H_FLOAT, T_FLOAT, "%6.2f", "deg",
 	"pos.posAng;instr.det", "deg"},
   {"AWIN_WORLD", "Windowed profile RMS along major axis (world units)",
 	&outobj2.win_aw, H_FLOAT, T_FLOAT, "%12.7g", "deg",
@@ -517,7 +551,7 @@ keystruct	objkey[] = {
 	&outobj2.win_bw, H_FLOAT, T_FLOAT, "%12.7g", "deg",
 	"phys.size.sminAxis", "deg"},
   {"THETAWIN_WORLD", "Windowed position angle (CCW/world-x)",
-	&outobj2.win_thetaw, H_FLOAT, T_FLOAT, "%5.1f", "deg",
+	&outobj2.win_thetaw, H_FLOAT, T_FLOAT, "%6.2f", "deg",
 	"pos.posAng", "deg"},
   {"THETAWIN_SKY", "Windowed position angle (east of north) (native)",
 	&outobj2.win_thetas, H_FLOAT, T_FLOAT, "%+6.2f", "deg",
@@ -530,22 +564,22 @@ keystruct	objkey[] = {
 	"pos.posAng", "deg"},
 
   {"ERRX2WIN_IMAGE", "Variance of windowed pos along x",
-	&outobj2.winposerr_mx2, H_EXPO, T_DOUBLE, "%15.10e", "pixel**2",
+	&outobj2.winposerr_mx2, H_EXPO, T_DOUBLE, "%18.10e", "pixel**2",
 	"stat.variance;pos.errorEllipse;instr.det", "pix2"},
   {"ERRY2WIN_IMAGE", "Variance of windowed pos along y",
-	&outobj2.winposerr_my2, H_EXPO, T_DOUBLE, "%15.10e", "pixel**2",
+	&outobj2.winposerr_my2, H_EXPO, T_DOUBLE, "%18.10e", "pixel**2",
 	"stat.variance;pos.errorEllipse;instr.det", "pix2"},
   {"ERRXYWIN_IMAGE", "Covariance of windowed pos between x and y",
-	&outobj2.winposerr_mxy, H_EXPO, T_DOUBLE, "%15.10e", "pixel**2",
+	&outobj2.winposerr_mxy, H_EXPO, T_DOUBLE, "%18.10e", "pixel**2",
 	"stat.covariance;pos.errorEllipse;instr.det", "pix2"},
   {"ERRX2WIN_WORLD", "Variance of windowed pos along X-WORLD (alpha)",
-	&outobj2.winposerr_mx2w, H_EXPO, T_DOUBLE, "%15.10e", "deg**2",
+	&outobj2.winposerr_mx2w, H_EXPO, T_DOUBLE, "%18.10e", "deg**2",
 	"stat.variance;pos.errorEllipse", "deg2"},
   {"ERRY2WIN_WORLD", "Variance of windowed pos along Y-WORLD (delta)",
-	&outobj2.winposerr_my2w, H_EXPO, T_DOUBLE, "%15.10e", "deg**2",
+	&outobj2.winposerr_my2w, H_EXPO, T_DOUBLE, "%18.10e", "deg**2",
 	"stat.variance;pos.errorEllipse", "deg2"},
   {"ERRXYWIN_WORLD", "Covariance of windowed pos X-WORLD/Y-WORLD",
-	&outobj2.winposerr_mxyw, H_EXPO, T_DOUBLE, "%15.10e", "deg**2",
+	&outobj2.winposerr_mxyw, H_EXPO, T_DOUBLE, "%18.10e", "deg**2",
 	"stat.covariance;pos.errorEllipse", "deg2"},
 
   {"ERRCXXWIN_IMAGE", "Cxx windowed error ellipse parameter",
@@ -568,13 +602,13 @@ keystruct	objkey[] = {
 	"src.impactParam;pos.errorEllipse", "deg-2"},
 
   {"ERRAWIN_IMAGE", "RMS windowed pos error along major axis",
-	&outobj2.winposerr_a, H_FLOAT, T_FLOAT, "%8.4f", "pixel",
+	&outobj2.winposerr_a, H_FLOAT, T_FLOAT, "%9.5f", "pixel",
 	"stat.stdev;stat.max;pos.errorEllipse;instr.det", "pix"},
   {"ERRBWIN_IMAGE", "RMS windowed pos error along minor axis",
-	&outobj2.winposerr_b, H_FLOAT, T_FLOAT, "%8.4f", "pixel",
+	&outobj2.winposerr_b, H_FLOAT, T_FLOAT, "%9.5f", "pixel",
 	"stat.stdev;stat.min;pos.errorEllipse;instr.det", "pix"},
   {"ERRTHETAWIN_IMAGE", "Windowed error ellipse pos angle (CCW/x)",
-	&outobj2.winposerr_theta, H_FLOAT, T_FLOAT, "%5.1f", "deg",
+	&outobj2.winposerr_theta, H_FLOAT, T_FLOAT, "%6.2f", "deg",
 	"pos.posAng;pos.errorEllipse;instr.det", "deg"},
   {"ERRAWIN_WORLD", "World RMS windowed pos error along major axis",
 	&outobj2.winposerr_aw, H_FLOAT, T_FLOAT, "%12.7g", "deg",
@@ -583,23 +617,23 @@ keystruct	objkey[] = {
 	&outobj2.winposerr_bw, H_FLOAT, T_FLOAT, "%12.7g", "deg",
 	"stat.stdev;stat.min;pos.errorEllipse", "deg"},
   {"ERRTHETAWIN_WORLD", "Windowed error ellipse pos. angle (CCW/world-x)",
-	&outobj2.winposerr_thetaw, H_FLOAT, T_FLOAT, "%5.1f", "deg",
+	&outobj2.winposerr_thetaw, H_FLOAT, T_FLOAT, "%6.2f", "deg",
 	"pos.posAng;pos.errorEllipse", "deg"},
   {"ERRTHETAWIN_SKY", "Native windowed error ellipse pos. angle (east of north)",
-	&outobj2.winposerr_thetas, H_FLOAT, T_FLOAT, "%5.1f", "deg",
+	&outobj2.winposerr_thetas, H_FLOAT, T_FLOAT, "%6.2f", "deg",
 	"pos.posAng;pos.errorEllipse", "deg"},
   {"ERRTHETAWIN_J2000", "J2000 windowed error ellipse pos. angle (east of north)",
-	&outobj2.winposerr_theta2000, H_FLOAT, T_FLOAT, "%5.1f", "deg",
+	&outobj2.winposerr_theta2000, H_FLOAT, T_FLOAT, "%6.2f", "deg",
 	"pos.posAng;pos.errorEllipse", "deg"},
   {"ERRTHETAWIN_B1950", "B1950 windowed error ellipse pos. angle (east of north)",
-	&outobj2.winposerr_theta1950, H_FLOAT, T_FLOAT, "%5.1f", "deg",
+	&outobj2.winposerr_theta1950, H_FLOAT, T_FLOAT, "%6.2f", "deg",
 	"pos.posAng;pos.errorEllipse", "deg"},
 
   {"NITER_WIN", "Number of iterations for WIN centering",
 	&outobj2.winpos_niter, H_INT, T_SHORT, "%3d", "",
 	"meta.number", ""},
 
-  {"MU_THRESHOLD", "Detection threshold above background",
+  {"MU_THRESHOLD", "Analysis threshold above background",
 	&outobj2.threshmu, H_FLOAT, T_FLOAT, "%8.4f", "mag * arcsec**(-2)",
 	"instr.sensitivity;phot.mag.sb", "mag.arcsec-2"},
   {"MU_MAX", "Peak surface brightness above background",
@@ -651,6 +685,12 @@ keystruct	objkey[] = {
   {"NIMAFLAGS_ISO", "Number of flagged pixels entering IMAFLAGS_ISO",
 	outobj.imanflag, H_INT, T_LONG, "%9d", "",
 	"meta.number", "", 1, &prefs.imanflag_size},
+  {"NLOWWEIGHT_ISO", "Nb of pixels with low weight over the iso. profile",
+	&outobj.nzwpix, H_INT, T_LONG, "%9d", "",
+	"meta.number", ""},
+  {"NLOWDWEIGHT_ISO", "Nb of pixels with low det. weight over the iso. profile",
+	&outobj.nzdwpix, H_INT, T_LONG, "%9d", "",
+	"meta.number", ""},
 
   {"FWHM_IMAGE", "FWHM assuming a gaussian core",
 	&outobj.fwhm, H_FLOAT, T_FLOAT, "%8.2f", "pixel",
@@ -677,7 +717,7 @@ keystruct	objkey[] = {
 	&outobj2.win_polarw, H_FLOAT, T_FLOAT, "%7.5f", "",
 	"src.ellipticity", ""},
   {"CLASS_STAR", "S/G classifier output",
-	&outobj2.sprob, H_FLOAT, T_FLOAT, "%5.2f", "",
+	&outobj2.sprob, H_FLOAT, T_FLOAT, "%6.3f", "",
 	"src.class.starGalaxy", ""},
   {"VIGNET", "Pixel data around detection",
 	&outobj2.vignet, H_FLOAT, T_FLOAT, "%12.7g", "count",
@@ -686,7 +726,7 @@ keystruct	objkey[] = {
 	&outobj2.vigshift, H_FLOAT, T_FLOAT, "%12.7g", "count",
 	"obs.image", "ct", 2, prefs.vigshiftsize},
   {"VECTOR_ASSOC", "ASSOCiated parameter vector",
-	&outobj2.assoc, H_FLOAT, T_FLOAT, "%12.7g", "",
+	&outobj2.assoc, H_FLOAT, T_DOUBLE, "%12.7g", "",
 	"src", "", 1, &prefs.assoc_size},
   {"NUMBER_ASSOC", "Number of ASSOCiated IDs",
 	&outobj2.assoc_number, H_INT, T_LONG, "%10d", "",
@@ -712,52 +752,59 @@ keystruct	objkey[] = {
 	&outobj2.flux_radius, H_FLOAT, T_FLOAT, "%10.3f", "pixel",
 	"phys.size.radius;instr.det", "pix",  1, &prefs.flux_radiussize},
 
+  {"FWHMPSF_IMAGE", "FWHM of the local PSF model",
+	&outobj2.fwhm_psf, H_FLOAT, T_FLOAT, "%8.3f", "pixel",
+	"phys.size.diameter;instr.det.psf", "pix"},
+  {"FWHMPSF_WORLD", "FWHM of the local PSF model (world units)",
+	&outobj2.fwhmw_psf, H_FLOAT, T_FLOAT, "%12.7g", "deg",
+	"phys.angSize;instr.det.psf", "deg"},
+
   {"XPSF_IMAGE", "X coordinate from PSF-fitting",
-	&outobj2.x_psf, H_FLOAT, T_FLOAT, "%10.3f", "pixel",
-	"pos.cartesian.x;stat.fit.param;instr.det", "pix", 1, &prefs.psf_xsize},
+	&outobj2.x_psf, H_FLOAT, T_DOUBLE, "%11.4f", "pixel",
+	"pos.cartesian.x;stat.fit.param;instr.det", "pix"},
   {"YPSF_IMAGE", "Y coordinate from PSF-fitting",
-	&outobj2.y_psf, H_FLOAT, T_FLOAT, "%10.3f", "pixel",
-	"pos.cartesian.y;stat.fit.param;instr.det", "pix", 1, &prefs.psf_ysize},
+	&outobj2.y_psf, H_FLOAT, T_DOUBLE, "%11.4f", "pixel",
+	"pos.cartesian.y;stat.fit.param;instr.det", "pix"},
   {"XPSF_WORLD", "PSF position along world x axis",
-	&outobj2.xw_psf, H_FLOAT, T_DOUBLE, "%15.10e", "deg",
-	"pos.eq.ra;stat.fit.param", "deg", 1, &prefs.psf_xwsize},
+	&outobj2.xw_psf, H_FLOAT, T_DOUBLE, "%18.10e", "deg",
+	"pos.eq.ra;stat.fit.param", "deg"},
   {"YPSF_WORLD", "PSF position along world y axis",
-	&outobj2.yw_psf, H_FLOAT, T_DOUBLE, "%15.10e", "deg",
-	"pos.eq.dec;stat.fit.param", "deg", 1, &prefs.psf_ywsize},
+	&outobj2.yw_psf, H_FLOAT, T_DOUBLE, "%18.10e", "deg",
+	"pos.eq.dec;stat.fit.param", "deg"},
 
   {"ALPHAPSF_SKY", "Right ascension of the fitted PSF (native)",
 	&outobj2.alphas_psf, H_FLOAT, T_DOUBLE, "%11.7f", "deg",
-	"pos.eq.ra;stat.fit.param", "deg", 1, &prefs.psf_alphassize},
+	"pos.eq.ra;stat.fit.param", "deg"},
   {"DELTAPSF_SKY", "Declination of the fitted PSF (native)",
 	&outobj2.deltas_psf, H_FLOAT, T_DOUBLE, "%+11.7f", "deg",
-	"pos.eq.dec;stat.fit.param", "deg", 1, &prefs.psf_deltassize},
+	"pos.eq.dec;stat.fit.param", "deg"},
 
   {"ALPHAPSF_J2000", "Right ascension of the fitted PSF (J2000)",
 	&outobj2.alpha2000_psf, H_FLOAT, T_DOUBLE, "%11.7f", "deg",
-	"pos.eq.ra;stat.fit.param", "deg", 1, &prefs.psf_alpha2000size},
+	"pos.eq.ra;stat.fit.param", "deg"},
   {"DELTAPSF_J2000", "Declination of the fitted PSF (J2000)",
 	&outobj2.delta2000_psf, H_FLOAT, T_DOUBLE, "%+11.7f", "deg",
-	"pos.eq.dec;stat.fit.param", "deg", 1, &prefs.psf_delta2000size},
+	"pos.eq.dec;stat.fit.param", "deg"},
 
   {"ALPHAPSF_B1950", "Right ascension of the fitted PSF (B1950)",
 	&outobj2.alpha1950_psf, H_FLOAT, T_DOUBLE, "%11.7f", "deg",
-	"pos.eq.ra;stat.fit.param", "deg", 1, &prefs.psf_alpha1950size},
+	"pos.eq.ra;stat.fit.param", "deg"},
   {"DELTAPSF_B1950", "Declination of the fitted PSF (B1950)",
 	&outobj2.delta1950_psf, H_FLOAT, T_DOUBLE, "%+11.7f", "deg",
-	"pos.eq.dec;stat.fit.param", "deg", 1, &prefs.psf_delta1950size},
+	"pos.eq.dec;stat.fit.param", "deg"},
 
   {"FLUX_PSF", "Flux from PSF-fitting",
 	&outobj2.flux_psf, H_FLOAT, T_FLOAT, "%12.7g", "count",
-	"phot.count;stat.fit.param", "ct", 1, &prefs.psf_fluxsize},
+	"phot.count;stat.fit.param", "ct"},
   {"FLUXERR_PSF", "RMS flux error for PSF-fitting",
 	&outobj2.fluxerr_psf, H_FLOAT, T_FLOAT, "%12.7g", "count",
-	"stat.stdev;phot.count", "ct", 1, &prefs.psf_fluxerrsize},
+	"stat.stdev;phot.count", "ct"},
   {"MAG_PSF", "Magnitude from PSF-fitting",
 	&outobj2.mag_psf, H_FLOAT, T_FLOAT, "%8.4f", "mag",
-	"phot.mag", "mag", 1, &prefs.psf_magsize},
+	"phot.mag", "mag"},
   {"MAGERR_PSF", "RMS magnitude error from PSF-fitting",
 	&outobj2.magerr_psf, H_FLOAT, T_FLOAT, "%8.4f", "mag",
-	"stat.stdev;phot.mag", "mag", 1, &prefs.psf_magsize},
+	"stat.stdev;phot.mag", "mag"},
 
   {"NITER_PSF", "Number of iterations for PSF-fitting",
 	&outobj2.niter_psf, H_INT, T_SHORT, "%3d", "",
@@ -767,22 +814,22 @@ keystruct	objkey[] = {
 	"stat.fit.chi2", ""},
 
   {"ERRX2PSF_IMAGE", "Variance of PSF position along x",
-	&outobj2.poserrmx2_psf, H_EXPO, T_DOUBLE, "%15.10e", "pixel**2",
+	&outobj2.poserrmx2_psf, H_EXPO, T_DOUBLE, "%18.10e", "pixel**2",
 	"stat.variance;pos.errorEllipse;instr.det", "pix2"},
   {"ERRY2PSF_IMAGE", "Variance of PSF position along y",
-	&outobj2.poserrmy2_psf, H_EXPO, T_DOUBLE, "%15.10e", "pixel**2",
+	&outobj2.poserrmy2_psf, H_EXPO, T_DOUBLE, "%18.10e", "pixel**2",
 	"stat.variance;pos.errorEllipse;instr.det", "pix2"},
   {"ERRXYPSF_IMAGE", "Covariance of PSF position between x and y",
-	&outobj2.poserrmxy_psf, H_EXPO, T_DOUBLE, "%15.10e", "pixel**2",
+	&outobj2.poserrmxy_psf, H_EXPO, T_DOUBLE, "%18.10e", "pixel**2",
 	"stat.covariance;pos.errorEllipse;instr.det", "pix2"},
   {"ERRX2PSF_WORLD", "Variance of PSF position along X-WORLD (alpha)",
-	&outobj2.poserrmx2w_psf, H_EXPO, T_DOUBLE, "%15.10e", "deg**2",
+	&outobj2.poserrmx2w_psf, H_EXPO, T_DOUBLE, "%18.10e", "deg**2",
 	"stat.variance;pos.errorEllipse", "deg2"},
   {"ERRY2PSF_WORLD", "Variance of PSF position along Y-WORLD (delta)",
-	&outobj2.poserrmy2w_psf, H_EXPO, T_DOUBLE, "%15.10e", "deg**2",
+	&outobj2.poserrmy2w_psf, H_EXPO, T_DOUBLE, "%18.10e", "deg**2",
 	"stat.variance;pos.errorEllipse", "deg2"},
   {"ERRXYPSF_WORLD", "Covariance of PSF position X-WORLD/Y-WORLD",
-	&outobj2.poserrmxyw_psf, H_EXPO, T_DOUBLE, "%15.10e", "deg**2",
+	&outobj2.poserrmxyw_psf, H_EXPO, T_DOUBLE, "%18.10e", "deg**2",
 	"stat.covariance;pos.errorEllipse", "deg2"},
 
   {"ERRCXXPSF_IMAGE", "Cxx PSF error ellipse parameter",
@@ -805,13 +852,13 @@ keystruct	objkey[] = {
 	"src.impactParam;pos.errorEllipse", "deg-2"},
 
   {"ERRAPSF_IMAGE", "PSF RMS position error along major axis",
-	&outobj2.poserra_psf, H_FLOAT, T_FLOAT, "%8.4f", "pixel",
+	&outobj2.poserra_psf, H_FLOAT, T_FLOAT, "%9.5f", "pixel",
 	"stat.stdev;stat.max;pos.errorEllipse;instr.det", "pix"},
   {"ERRBPSF_IMAGE", "PSF RMS position error along minor axis",
-	&outobj2.poserrb_psf, H_FLOAT, T_FLOAT, "%8.4f", "pixel",
+	&outobj2.poserrb_psf, H_FLOAT, T_FLOAT, "%9.5f", "pixel",
 	"stat.stdev;stat.min;pos.errorEllipse;instr.det", "pix"},
-  {"ERRTHTPSF_IMAGE", "PSF error ellipse position angle (CCW/x)",
-	&outobj2.poserrtheta_psf, H_FLOAT, T_FLOAT, "%5.1f", "deg",
+  {"ERRTHETAPSF_IMAGE", "PSF error ellipse position angle (CCW/x)",
+	&outobj2.poserrtheta_psf, H_FLOAT, T_FLOAT, "%6.2f", "deg",
 	"pos.posAng;pos.errorEllipse;instr.det", "deg"},
   {"ERRAPSF_WORLD", "World PSF RMS position error along major axis",
 	&outobj2.poserraw_psf, H_FLOAT, T_FLOAT, "%12.7g", "pixel",
@@ -819,28 +866,32 @@ keystruct	objkey[] = {
   {"ERRBPSF_WORLD", "World PSF RMS position error along minor axis",
 	&outobj2.poserrbw_psf, H_FLOAT, T_FLOAT, "%12.7g", "pixel",
 	"stat.stdev;stat.min;pos.errorEllipse", "deg"},
-  {"ERRTHTPSF_WORLD", "PSF error ellipse pos. angle (CCW/world-x)",
-	&outobj2.poserrthetaw_psf, H_FLOAT, T_FLOAT, "%5.1f", "deg",
+  {"ERRTHETAPSF_WORLD", "PSF error ellipse pos. angle (CCW/world-x)",
+	&outobj2.poserrthetaw_psf, H_FLOAT, T_FLOAT, "%6.2f", "deg",
 	"pos.posAng;pos.errorEllipse", "deg"},
-  {"ERRTHTPSF_SKY", "Native PSF error ellipse pos. angle (east of north)",
-	&outobj2.poserrthetas_psf, H_FLOAT, T_FLOAT, "%5.1f", "deg",
+  {"ERRTHETAPSF_SKY", "Native PSF error ellipse pos. angle (east of north)",
+	&outobj2.poserrthetas_psf, H_FLOAT, T_FLOAT, "%6.2f", "deg",
 	"pos.posAng;pos.errorEllipse", "deg"},
-  {"ERRTHTPSF_J2000", "J2000 PSF error ellipse pos. angle (east of north)",
-	&outobj2.poserrtheta2000_psf, H_FLOAT, T_FLOAT, "%5.1f", "deg",
+  {"ERRTHETAPSF_J2000", "J2000 PSF error ellipse pos. angle (east of north)",
+	&outobj2.poserrtheta2000_psf, H_FLOAT, T_FLOAT, "%6.2f", "deg",
 	"pos.posAng;pos.errorEllipse", "deg"},
-  {"ERRTHTPSF_B1950", "B1950 PSF error ellipse pos. angle (east of north)",
-	&outobj2.poserrtheta1950_psf, H_FLOAT, T_FLOAT, "%5.1f", "deg",
+  {"ERRTHETAPSF_B1950", "B1950 PSF error ellipse pos. angle (east of north)",
+	&outobj2.poserrtheta1950_psf, H_FLOAT, T_FLOAT, "%6.2f", "deg",
 	"pos.posAng;pos.errorEllipse", "deg"},
 
+  {"DURATION_ANALYSIS", "Duration of analysis for this source",
+	&outobj2.analtime, H_FLOAT, T_FLOAT, "%9.4g", "s",
+	"time.duration;time.processing", "s"},
+
 /* Temporarily (at least) deactivated not to confuse users with model-fitting
   {"X2PC_IMAGE", "PC variance along x",
-	&outobj2.mx2_pc, H_EXPO, T_DOUBLE, "%15.10e", "pixel**2",
+	&outobj2.mx2_pc, H_EXPO, T_DOUBLE, "%18.10e", "pixel**2",
 	"src.impactParam;instr.det", "pix2"},
   {"Y2PC_IMAGE", "PC variance along y",
-	&outobj2.my2_pc, H_EXPO, T_DOUBLE, "%15.10e", "pixel**2",
+	&outobj2.my2_pc, H_EXPO, T_DOUBLE, "%18.10e", "pixel**2",
 	"src.impactParam;instr.det", "pix2"},
   {"XYPC_IMAGE", "PC covariance between x and y",
-	&outobj2.mxy_pc, H_EXPO, T_DOUBLE, "%15.10e", "pixel**2",
+	&outobj2.mxy_pc, H_EXPO, T_DOUBLE, "%18.10e", "pixel**2",
 	"src.impactParam;instr.det", "pix2"},
 
   {"APC_IMAGE", "PC profile RMS along major axis",
@@ -850,14 +901,16 @@ keystruct	objkey[] = {
 	&outobj2.b_pc, H_FLOAT, T_FLOAT, "%8.2f", "pixel",
 	"phys.size.sminAxis;instr.det", "pix"},
   {"THETAPC_IMAGE", "PC position angle (CCW/x)",
-	&outobj2.theta_pc, H_FLOAT, T_FLOAT, "%5.1f", "deg",
+	&outobj2.theta_pc, H_FLOAT, T_FLOAT, "%6.2f", "deg",
 	"pos.posAng;instr.det", "deg"},
   {"PC", "Principal components",
-	&outobj2.vector_pc, H_FLOAT, T_FLOAT, "%15.10e", "",
+	&outobj2.vector_pc, H_FLOAT, T_FLOAT, "%18.10e", "",
 	"src.morph.param", "", 1, &prefs.pc_vectorsize},
 */
 
+#ifdef USE_MODEL
 #include "paramprofit.h"
+#endif
 
   {""}
   };
