@@ -1,18 +1,30 @@
 /*
- 				paramprofit.h
-
-*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+*				paramprofit.h
 *
-*	Part of:	SExtractor
+* List model-fitting measurement parameters.
 *
-*	Author:		E.BERTIN (IAP)
+*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 *
-*	Contents:	Model-fitting parameter list for catalog data.
+*	This file part of:	SExtractor
 *
-*	Last modify:	23/03/2009
+*	Copyright:		(C) 2007-2013 Emmanuel Bertin -- IAP/CNRS/UPMC
 *
-*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-*/
+*	License:		GNU General Public License
+*
+*	SExtractor is free software: you can redistribute it and/or modify
+*	it under the terms of the GNU General Public License as published by
+*	the Free Software Foundation, either version 3 of the License, or
+*	(at your option) any later version.
+*	SExtractor is distributed in the hope that it will be useful,
+*	but WITHOUT ANY WARRANTY; without even the implied warranty of
+*	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+*	GNU General Public License for more details.
+*	You should have received a copy of the GNU General Public License
+*	along with SExtractor. If not, see <http://www.gnu.org/licenses/>.
+*
+*	Last modified:		05/07/2013
+*
+*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%*/
 
   {"VECTOR_MODEL", "Model-fitting coefficients",
 	&outobj2.prof_vector, H_FLOAT, T_FLOAT, "%12.4g", "",
@@ -21,6 +33,10 @@
 	&outobj2.prof_errvector, H_FLOAT, T_FLOAT, "%12.4g", "",
 	"stat.stdev;stat.fit;src.morph.param", "", 1,
 	&prefs.prof_errvectorsize},
+  {"MATRIX_MODELERR", "Model-fitting covariance matrix",
+	&outobj2.prof_errmatrix, H_FLOAT, T_FLOAT, "%12.4g", "",
+	"stat.covariance;stat.fit;src.morph.param", "", 2,
+	prefs.prof_errmatrixsize},
   {"CHI2_MODEL", "Reduced Chi2 of the fit",
 	&outobj2.prof_chi2, H_FLOAT, T_FLOAT, "%12.7g", "",
 	"stat.fit.chi2;src.morph", ""},
@@ -30,6 +46,7 @@
   {"NITER_MODEL", "Number of iterations for model-fitting",
 	&outobj2.prof_niter, H_INT, T_SHORT, "%3d", "",
 	"meta.number;stat.fit;src.morph", ""},
+
   {"FLUX_MODEL", "Flux from model-fitting",
 	&outobj2.flux_prof, H_FLOAT, T_FLOAT, "%12.7g", "count",
 	"phot.count;stat.fit.param", "ct"},
@@ -40,21 +57,60 @@
 	&outobj2.mag_prof, H_FLOAT, T_FLOAT, "%8.4f", "mag",
 	"phot.mag;stat.fit.param", "mag"},
   {"MAGERR_MODEL", "RMS error on model-fitting magnitude",
-	&outobj2.mag_prof, H_FLOAT, T_FLOAT, "%8.4f", "mag",
+	&outobj2.magerr_prof, H_FLOAT, T_FLOAT, "%8.4f", "mag",
 	"stat.error;phot.mag;stat.fit.param", "mag"},
 
+  {"FLUX_HYBRID", "Hybrid flux from model-fitting",
+	&outobj2.fluxcor_prof, H_FLOAT, T_FLOAT, "%12.7g", "count",
+	"phot.count;stat.fit.param", "ct"},
+  {"FLUXERR_HYBRID", "RMS error on hybrid flux",
+	&outobj2.fluxcorerr_prof, H_FLOAT, T_FLOAT, "%12.7g", "count",
+	"stat.error;phot.count;stat.fit.param", "ct"},
+  {"MAG_HYBRID", "Hybrid magnitude from model-fitting",
+	&outobj2.magcor_prof, H_FLOAT, T_FLOAT, "%8.4f", "mag",
+	"phot.mag;stat.fit.param", "mag"},
+  {"MAGERR_HYBRID", "RMS error on hybrid magnitude",
+	&outobj2.magcorerr_prof, H_FLOAT, T_FLOAT, "%8.4f", "mag",
+	"stat.error;phot.mag;stat.fit.param", "mag"},
+
+  {"FLUX_MAX_MODEL", "Peak model flux above background",
+	&outobj2.peak_prof, H_FLOAT, T_FLOAT, "%12.7g", "count",
+	"phot.flux.sb;stat.max;stat.fit.param", "ct"},
+  {"FLUX_EFF_MODEL", "Effective model flux above background",
+	&outobj2.fluxeff_prof, H_FLOAT, T_FLOAT, "%12.7g", "count",
+	"phot.flux.sb;stat.fit.param", "ct"},
+  {"FLUX_MEAN_MODEL", "Mean effective model flux above background",
+	&outobj2.fluxmean_prof, H_FLOAT, T_FLOAT, "%12.7g", "count",
+	"phot.flux.sb;stat.mean;stat.fit.param", "ct"},
+  {"MU_MAX_MODEL", "Peak model surface brightness above background",
+	&outobj2.mumax_prof, H_FLOAT, T_FLOAT, "%8.4f", "mag * arcsec**(-2)",
+	"phot.mag.sb;stat.max;stat.fit.param", "mag.arcsec-2"},
+  {"MU_EFF_MODEL", "Effective model surface brightness above background",
+	&outobj2.mueff_prof, H_FLOAT, T_FLOAT, "%8.4f", "mag * arcsec**(-2)",
+	"phot.mag.sb;stat.fit.param", "mag.arcsec-2"},
+  {"MU_MEAN_MODEL", "Mean effective model surface brightness above background",
+	&outobj2.mumean_prof, H_FLOAT, T_FLOAT, "%8.4f", "mag * arcsec**(-2)",
+	"phot.mag.sb;stat.mean;stat.fit.param", "mag.arcsec-2"},
+
   {"XMODEL_IMAGE", "X coordinate from model-fitting",
-	&outobj2.x_prof, H_FLOAT, T_FLOAT, "%10.3f", "pixel",
+	&outobj2.x_prof, H_FLOAT, T_DOUBLE, "%11.4f", "pixel",
 	"pos.cartesian.x;stat.fit.param;instr.det;meta.main", "pix"},
   {"YMODEL_IMAGE", "Y coordinate from model-fitting",
-	&outobj2.y_prof, H_FLOAT, T_FLOAT, "%10.3f", "pixel",
+	&outobj2.y_prof, H_FLOAT, T_DOUBLE, "%11.4f", "pixel",
 	"pos.cartesian.y;stat.fit.param;instr.det;meta.main", "pix"},
 
+  {"XFOCAL_WORLD", "Fitted position along focal-plane x axis",
+	&outobj2.xf_prof, H_FLOAT, T_DOUBLE, "%18.10e", "",
+	"pos.cartesian.x;stat.fit.param", ""},
+  {"YFOCAL_WORLD", "Fitted position along focal-plane y axis",
+	&outobj2.yf_prof, H_FLOAT, T_DOUBLE, "%18.10e", "",
+	"pos.cartesian.y;stat.fit.param", ""},
+
   {"XMODEL_WORLD", "Fitted position along world x axis",
-	&outobj2.xw_prof, H_FLOAT, T_DOUBLE, "%15.10e", "deg",
+	&outobj2.xw_prof, H_FLOAT, T_DOUBLE, "%18.10e", "deg",
 	"pos.eq.ra;stat.fit.param", "deg"},
   {"YMODEL_WORLD", "Fitted position along world y axis",
-	&outobj2.yw_prof, H_FLOAT, T_DOUBLE, "%15.10e", "deg",
+	&outobj2.yw_prof, H_FLOAT, T_DOUBLE, "%18.10e", "deg",
 	"pos.eq.dec;stat.fit.param", "deg"},
 
   {"ALPHAMODEL_SKY", "Fitted position along right ascension  (native)",
@@ -79,22 +135,22 @@
 	"pos.eq.dec;stat.fit.param", "deg"},
 
   {"ERRX2MODEL_IMAGE", "Variance of fitted position along x",
-	&outobj2.poserrmx2_prof, H_EXPO, T_DOUBLE, "%15.10e", "pixel**2",
+	&outobj2.poserrmx2_prof, H_EXPO, T_DOUBLE, "%18.10e", "pixel**2",
 	"stat.variance;pos.errorEllipse;stat.fit.param;instr.det", "pix2"},
   {"ERRY2MODEL_IMAGE", "Variance of fitted position along y",
-	&outobj2.poserrmy2_prof, H_EXPO, T_DOUBLE, "%15.10e", "pixel**2",
+	&outobj2.poserrmy2_prof, H_EXPO, T_DOUBLE, "%18.10e", "pixel**2",
 	"stat.variance;pos.errorEllipse;stat.fit.param;instr.det", "pix2"},
   {"ERRXYMODEL_IMAGE", "Covariance of fitted position between x and y",
-	&outobj2.poserrmxy_prof, H_EXPO, T_DOUBLE, "%15.10e", "pixel**2",
+	&outobj2.poserrmxy_prof, H_EXPO, T_DOUBLE, "%18.10e", "pixel**2",
 	"stat.covariance;pos.errorEllipse;stat.fit.param;instr.det", "pix2"},
   {"ERRX2MODEL_WORLD", "Variance of fitted position along X-WORLD (alpha)",
-	&outobj2.poserrmx2w_prof, H_EXPO, T_DOUBLE, "%15.10e", "deg**2",
+	&outobj2.poserrmx2w_prof, H_EXPO, T_DOUBLE, "%18.10e", "deg**2",
 	"stat.variance;pos.errorEllipse;stat.fit.param", "deg2"},
   {"ERRY2MODEL_WORLD", "Variance of fitted position along Y-WORLD (delta)",
-	&outobj2.poserrmy2w_prof, H_EXPO, T_DOUBLE, "%15.10e", "deg**2",
+	&outobj2.poserrmy2w_prof, H_EXPO, T_DOUBLE, "%18.10e", "deg**2",
 	"stat.variance;pos.errorEllipse;stat.fit.param", "deg2"},
   {"ERRXYMODEL_WORLD", "Covariance of fitted position X-WORLD/Y-WORLD",
-	&outobj2.poserrmxyw_prof, H_EXPO, T_DOUBLE, "%15.10e", "deg**2",
+	&outobj2.poserrmxyw_prof, H_EXPO, T_DOUBLE, "%18.10e", "deg**2",
 	"stat.covariance;pos.errorEllipse;stat.fit.param", "deg2"},
 
   {"ERRCXXMODEL_IMAGE", "Cxx error ellipse parameter of fitted position",
@@ -117,13 +173,13 @@
 	"src.impactParam;pos.errorEllipsestat.fit.param", "deg-2"},
 
   {"ERRAMODEL_IMAGE", "RMS error of fitted position along major axis",
-	&outobj2.poserra_prof, H_FLOAT, T_FLOAT, "%8.4f", "pixel",
+	&outobj2.poserra_prof, H_FLOAT, T_FLOAT, "%9.5f", "pixel",
 	"stat.stdev;stat.max;pos.errorEllipse;stat.fit.param;instr.det", "pix"},
   {"ERRBMODEL_IMAGE", "RMS error of fitted position along minor axis",
-	&outobj2.poserrb_prof, H_FLOAT, T_FLOAT, "%8.4f", "pixel",
+	&outobj2.poserrb_prof, H_FLOAT, T_FLOAT, "%9.5f", "pixel",
 	"stat.stdev;stat.min;pos.errorEllipse;stat.fit.param;instr.det", "pix"},
   {"ERRTHETAMODEL_IMAGE", "Error ellipse pos.angle of fitted position (CCW/x)",
-	&outobj2.poserrtheta_prof, H_FLOAT, T_FLOAT, "%5.1f", "deg",
+	&outobj2.poserrtheta_prof, H_FLOAT, T_FLOAT, "%6.2f", "deg",
 	"pos.posAng;pos.errorEllipse;stat.fit.param;instr.det", "deg"},
   {"ERRAMODEL_WORLD", "World RMS error of fitted position along major axis",
 	&outobj2.poserraw_prof, H_FLOAT, T_FLOAT, "%12.7g", "deg",
@@ -132,48 +188,166 @@
 	&outobj2.poserrbw_prof, H_FLOAT, T_FLOAT, "%12.7g", "deg",
 	"stat.stdev;stat.min;pos.errorEllipse;stat.fit.param", "deg"},
   {"ERRTHETAMODEL_WORLD", "Error ellipse pos.angle of fitted position (CCW/world-x)",
-	&outobj2.poserrthetaw_prof, H_FLOAT, T_FLOAT, "%5.1f", "deg",
+	&outobj2.poserrthetaw_prof, H_FLOAT, T_FLOAT, "%6.2f", "deg",
 	"pos.posAng;pos.errorEllipse;stat.fit.param", "deg"},
   {"ERRTHETAMODEL_SKY", "Native fitted error ellipse pos. angle (east of north)",
-	&outobj2.poserrthetas_prof, H_FLOAT, T_FLOAT, "%5.1f", "deg",
+	&outobj2.poserrthetas_prof, H_FLOAT, T_FLOAT, "%6.2f", "deg",
 	"pos.posAng;pos.errorEllipse;stat.fit.param", "deg"},
   {"ERRTHETAMODEL_J2000", "J2000 fitted error ellipse pos. angle (east of north)",
-	&outobj2.poserrtheta2000_prof, H_FLOAT, T_FLOAT, "%5.1f", "deg",
+	&outobj2.poserrtheta2000_prof, H_FLOAT, T_FLOAT, "%6.2f", "deg",
 	"pos.posAng;pos.errorEllipse;stat.fit.param", "deg"},
   {"ERRTHETAMODEL_B1950", "B1950 fitted error ellipse pos. angle (east of north)",
-	&outobj2.poserrtheta1950_prof, H_FLOAT, T_FLOAT, "%5.1f", "deg",
+	&outobj2.poserrtheta1950_prof, H_FLOAT, T_FLOAT, "%6.2f", "deg",
 	"pos.posAng;pos.errorEllipse;stat.fit.param", "deg"},
 
 
   {"X2MODEL_IMAGE", "Variance along x from model-fitting",
-	&outobj2.prof_mx2, H_EXPO, T_DOUBLE, "%15.10e", "pixel**2",
+	&outobj2.prof_mx2, H_EXPO, T_DOUBLE, "%18.10e", "pixel**2",
 	"src.impactParam;stat.fit;instr.det", "pix2"},
   {"Y2MODEL_IMAGE", "Variance along y from model-fitting",
-	&outobj2.prof_my2, H_EXPO, T_DOUBLE, "%15.10e", "pixel**2",
+	&outobj2.prof_my2, H_EXPO, T_DOUBLE, "%18.10e", "pixel**2",
 	"src.impactParam;stat.fit;instr.det", "pix2"},
   {"XYMODEL_IMAGE", "Covariance between x and y from model-fitting",
-	&outobj2.prof_mxy, H_EXPO, T_DOUBLE, "%15.10e", "pixel**2",
+	&outobj2.prof_mxy, H_EXPO, T_DOUBLE, "%18.10e", "pixel**2",
 	"src.impactParam;stat.fit;instr.det", "pix2"},
-  {"E1MODEL_IMAGE", "Ellipticity component from model-fitting",
+  {"ELLIP1MODEL_IMAGE", "Ellipticity component from model-fitting",
 	&outobj2.prof_e1, H_FLOAT, T_FLOAT, "%10.6f", "",
 	"src.ellipticity;stat.fit;instr.det", ""},
-  {"E2MODEL_IMAGE", "Ellipticity component from model-fitting",
+  {"ELLIP2MODEL_IMAGE", "Ellipticity component from model-fitting",
 	&outobj2.prof_e2, H_FLOAT, T_FLOAT, "%10.6f", "",
 	"src.ellipticity;stat.fit;instr.det", ""},
-  {"EPS1MODEL_IMAGE", "Ellipticity component (quadratic) from model-fitting",
-	&outobj2.prof_eps1, H_FLOAT, T_FLOAT, "%10.6f", "",
+  {"POLAR1MODEL_IMAGE", "Ellipticity component (quadratic) from model-fitting",
+	&outobj2.prof_pol1, H_FLOAT, T_FLOAT, "%10.6f", "",
 	"src.ellipticity;stat.fit;instr.det", ""},
-  {"EPS2MODEL_IMAGE", "Ellipticity component (quadratic) from model-fitting",
-	&outobj2.prof_eps2, H_FLOAT, T_FLOAT, "%10.6f", "",
+  {"POLAR2MODEL_IMAGE", "Ellipticity component (quadratic) from model-fitting",
+	&outobj2.prof_pol2, H_FLOAT, T_FLOAT, "%10.6f", "",
 	"src.ellipticity;stat.fit;instr.det", ""},
 
-  {"CONCENTRATION_MODEL", "Concentration parameter from model-fitting",
-	&outobj2.prof_concentration, H_FLOAT, T_FLOAT, "%7.4f", "",
+  {"ELLIP1ERRMODEL_IMAGE", "Ellipticity component std.error from model-fitting",
+	&outobj2.prof_e1err, H_FLOAT, T_FLOAT, "%10.6f", "",
+	"stat.error;src.ellipticity;stat.fit;instr.det", ""},
+  {"ELLIP2ERRMODEL_IMAGE", "Ellipticity component std.error from model-fitting",
+	&outobj2.prof_e2err, H_FLOAT, T_FLOAT, "%10.6f", "",
+	"stat.error;src.ellipticity;stat.fit;instr.det", ""},
+  {"ELLIPCORRMODEL_IMAGE", "Corr.coeff between ellip.components from model-fitting",
+	&outobj2.prof_e12corr, H_FLOAT, T_FLOAT, "%10.6f", "",
+	"stat.correlation;src.ellipticity;stat.fit;instr.det", ""},
+
+  {"POLAR1ERRMODEL_IMAGE", "Polarisation component std.error from model-fitting",
+	&outobj2.prof_pol1err, H_FLOAT, T_FLOAT, "%10.6f", "",
+	"stat.error;src.ellipticity;stat.fit;instr.det", ""},
+  {"POLAR2ERRMODEL_IMAGE", "Polarisation component std.error from model-fitting",
+	&outobj2.prof_pol2err, H_FLOAT, T_FLOAT, "%10.6f", "",
+	"stat.error;src.ellipticity;stat.fit;instr.det", ""},
+  {"POLARCORRMODEL_IMAGE", "Corr.coeff between polar. components from fitting",
+	&outobj2.prof_pol12corr, H_FLOAT, T_FLOAT, "%10.6f", "",
+	"stat.correlation;src.ellipticity;stat.fit;instr.det", ""},
+
+  {"X2MODEL_WORLD", "Variance along X-WORLD (alpha) from model-fitting",
+	&outobj2.prof_mx2w, H_EXPO, T_DOUBLE, "%18.10e", "deg**2",
+	"src.impactParam;stat.fit", "deg2"},
+  {"Y2MODEL_WORLD", "Variance along Y_WORLD (delta) from model-fitting",
+	&outobj2.prof_my2w, H_EXPO, T_DOUBLE, "%18.10e", "deg**2",
+	"src.impactParam;stat.fit", "deg2"},
+  {"XYMODEL_WORLD", "Covariance between X-WORLD and Y-WORLD from model-fitting",
+	&outobj2.prof_mxyw, H_EXPO, T_DOUBLE, "%18.10e", "deg**2",
+	"src.impactParam;stat.fit", "deg2"},
+  {"ELLIP1MODEL_WORLD", "Ellipticity component from model-fitting",
+	&outobj2.prof_e1w, H_FLOAT, T_FLOAT, "%10.6f", "",
+	"src.ellipticity;stat.fit", ""},
+  {"ELLIP2MODEL_WORLD", "Ellipticity component from model-fitting",
+	&outobj2.prof_e2w, H_FLOAT, T_FLOAT, "%10.6f", "",
+	"src.ellipticity;stat.fit", ""},
+  {"POLAR1MODEL_WORLD", "Polarisation component from model-fitting",
+	&outobj2.prof_pol1w, H_FLOAT, T_FLOAT, "%10.6f", "",
+	"src.ellipticity;stat.fit", ""},
+  {"POLAR2MODEL_WORLD", "Polarisation component from model-fitting",
+	&outobj2.prof_pol2w, H_FLOAT, T_FLOAT, "%10.6f", "",
+	"src.ellipticity;stat.fit", ""},
+
+  {"ELLIP1ERRMODEL_WORLD", "Ellipticity component std.error from model-fitting",
+	&outobj2.prof_e1errw, H_FLOAT, T_FLOAT, "%10.6f", "",
+	"stat.error;src.ellipticity;stat.fit", ""},
+  {"ELLIP2ERRMODEL_WORLD", "Ellipticity component std.error from model-fitting",
+	&outobj2.prof_e2errw, H_FLOAT, T_FLOAT, "%10.6f", "",
+	"stat.error;src.ellipticity;stat.fit", ""},
+  {"ELLIPCORRMODEL_WORLD", "Corr.coeff between ellip.components from model-fitting",
+	&outobj2.prof_e12corrw, H_FLOAT, T_FLOAT, "%10.6f", "",
+	"stat.correlation;src.ellipticity;stat.fit", ""},
+
+  {"POLAR1ERRMODEL_WORLD", "Polarisation component std.error from model-fitting",
+	&outobj2.prof_pol1errw, H_FLOAT, T_FLOAT, "%10.6f", "",
+	"stat.error;src.ellipticity;stat.fit", ""},
+  {"POLAR2ERRMODEL_WORLD", "Polarisation component std.error from model-fitting",
+	&outobj2.prof_pol2errw, H_FLOAT, T_FLOAT, "%10.6f", "",
+	"stat.error;src.ellipticity;stat.fit", ""},
+  {"POLARCORRMODEL_WORLD", "Corr.coeff between polar. components from fitting",
+	&outobj2.prof_pol12corrw, H_FLOAT, T_FLOAT, "%10.6f", "",
+	"stat.correlation;src.ellipticity;stat.fit", ""},
+
+  {"CXXMODEL_IMAGE", "Cxx ellipse parameter from model-fitting",
+	&outobj2.prof_cxx, H_EXPO, T_FLOAT, "%15.7e", "pixel**(-2)",
+	"src.impactParam;stat.fit;instr.det", "pix-2"},
+  {"CYYMODEL_IMAGE", "Cyy ellipse parameter from model-fittinh",
+	&outobj2.prof_cyy, H_EXPO, T_FLOAT, "%15.7e", "pixel**(-2)",
+	"src.impactParam;stat.fit;instr.det", "pix-2"},
+  {"CXYMODEL_IMAGE", "Cxy ellipse parameter from model-fitting",
+	&outobj2.prof_cxy, H_EXPO, T_FLOAT, "%15.7e", "pixel**(-2)",
+	"src.impactParam;stat.fit;instr.det", "pix-2"},
+  {"CXXMODEL_WORLD", "Cxx ellipse parameter (WORLD) from model-fitting",
+	&outobj2.prof_cxxw, H_EXPO, T_FLOAT, "%15.7e", "deg**(-2)",
+	"src.impactParam;stat.fit", "deg-2"},
+  {"CYYMODEL_WORLD", "Cyy ellipse parameter (WORLD) from model-fitting",
+	&outobj2.prof_cyyw, H_EXPO, T_FLOAT, "%15.7e", "deg**(-2)",
+	"src.impactParam;stat.fit", "deg-2"},
+  {"CXYMODEL_WORLD", "Cxy ellipse parameter (WORLD) from model-fitting",
+	&outobj2.prof_cxyw, H_EXPO, T_FLOAT, "%15.7e", "deg**(-2)",
+	"src.impactParam;stat.fit", "deg-2"},
+
+  {"AMODEL_IMAGE", "Model RMS along major axis",
+	&outobj2.prof_a, H_FLOAT, T_FLOAT, "%9.3f", "pixel",
+	"phys.size.smajAxis;stat.fit;instr.det", "pix"},
+  {"BMODEL_IMAGE", "Model RMS along minor axis",
+	&outobj2.prof_b, H_FLOAT, T_FLOAT, "%9.3f", "pixel",
+	"phys.size.sminAxis;stat.fit;instr.det", "pix"},
+  {"THETAMODEL_IMAGE", "Model position angle (CCW/x)",
+	&outobj2.prof_theta, H_FLOAT, T_FLOAT, "%6.2f", "deg",
+	"pos.posAng;stat.fit;instr.det", "deg"},
+  {"AMODEL_WORLD", "Model RMS along major axis (WORLD units)",
+	&outobj2.prof_aw, H_FLOAT, T_FLOAT, "%12.7g", "deg",
+	"phys.size.smajAxis;stat.fit", "deg"},
+  {"BMODEL_WORLD", "Model RMS along minor axis (WORLD units)",
+	&outobj2.prof_bw, H_FLOAT, T_FLOAT, "%12.7g", "deg",
+	"phys.size.sminAxis;stat.fit", "deg"},
+  {"THETAMODEL_WORLD", "Model position angle (CCW/WORLD-x)",
+	&outobj2.prof_thetaw, H_FLOAT, T_FLOAT, "%6.2f", "deg",
+	"pos.posAng;stat.fit", "deg"},
+  {"THETAMODEL_SKY", "Model position angle (east of north) (native)",
+	&outobj2.prof_thetas, H_FLOAT, T_FLOAT, "%+6.2f", "deg",
+	"pos.posAng;stat.fit", "deg"},
+  {"THETAMODEL_J2000", "Model position angle (east of north) (J2000)",
+	&outobj2.prof_theta2000, H_FLOAT, T_FLOAT, "%+6.2f", "deg",
+	"pos.posAng;stat.fit", "deg"},
+  {"THETAMODEL_B1950", "Model position angle (east of north) (B1950)",
+	&outobj2.prof_theta1950, H_FLOAT, T_FLOAT, "%+6.2f", "deg",
+	"pos.posAng;stat.fit", "deg"},
+
+  {"SPREAD_MODEL", "Spread parameter from model-fitting",
+	&outobj2.prof_concentration, H_FLOAT, T_FLOAT, "%11.5g", "",
 	"src.morph.param", ""},
+  {"SPREADERR_MODEL", "Spread parameter error from model-fitting",
+	&outobj2.prof_concentrationerr, H_FLOAT, T_FLOAT, "%11.5g", "",
+	"src.morph.param", ""},
+
+  {"NOISEAREA_MODEL", "Equivalent noise area of the fitted model",
+	&outobj2.prof_noisearea, H_FLOAT, T_FLOAT, "%12.2f", "pixel**2",
+	"phys.area", "pix2"},
+
+/*
   {"CLASS_STAR_MODEL", "S/G classifier from model-fitting",
 	&outobj2.prof_class_star, H_FLOAT, T_FLOAT, "%7.4f", "",
 	"src.class.starGalaxy", ""},
-
+*/
   {"FLUX_BACKOFFSET", "Background offset from fitting",
 	&outobj2.prof_offset_flux, H_FLOAT, T_FLOAT, "%12.7g", "count",
 	"instr.skyLevel;arith.diff;stat.fit.param", "ct"},
@@ -181,6 +355,25 @@
 	&outobj2.prof_offset_fluxerr, H_FLOAT, T_FLOAT, "%12.7g", "count",
 	"stat.error;instr.skyLevel;arith.diff;stat.fit.param", "ct"},
 
+  {"FLUX_POINTSOURCE", "Point source flux from fitting",
+	&outobj2.prof_dirac_flux, H_FLOAT, T_FLOAT, "%12.7g", "count",
+	"phot.count;stat.fit.param", "ct"},
+  {"FLUXERR_POINTSOURCE", "RMS error on fitted point source total flux",
+	&outobj2.prof_dirac_fluxerr, H_FLOAT, T_FLOAT, "%12.7g", "count",
+	"stat.error;phot.count;stat.fit.param", "ct"},
+  {"FLUXRATIO_POINTSOURCE", "Point-source flux-to-total ratio from fitting",
+	&outobj2.prof_dirac_fluxratio, H_FLOAT, T_FLOAT, "%7.5f", "",
+	"phot.count;stat.fit.param;arith.ratio", ""},
+  {"FLUXRATIOERR_POINTSOURCE", "RMS error on point-source flux-to-total ratio",
+	&outobj2.prof_dirac_fluxratioerr, H_FLOAT, T_FLOAT, "%7.5f", "",
+	"stat.error;phot.count;stat.fit.param;arith.ratio", ""},
+  {"MAG_POINTSOURCE", "Point source total magnitude from fitting",
+	&outobj2.prof_dirac_mag, H_FLOAT, T_FLOAT, "%8.4f", "mag",
+	"phot.mag;stat.fit.param", "mag"},
+  {"MAGERR_POINTSOURCE", "RMS error on fitted point source total magnitude",
+	&outobj2.prof_dirac_magerr, H_FLOAT, T_FLOAT, "%8.4f", "mag",
+	"stat.error;phot.mag;stat.fit.param", "mag"},
+
   {"FLUX_SPHEROID", "Spheroid total flux from fitting",
 	&outobj2.prof_spheroid_flux, H_FLOAT, T_FLOAT, "%12.7g", "count",
 	"phot.count;stat.fit.param", "ct"},
@@ -193,6 +386,30 @@
   {"MAGERR_SPHEROID", "RMS error on fitted spheroid total magnitude",
 	&outobj2.prof_spheroid_magerr, H_FLOAT, T_FLOAT, "%8.4f", "mag",
 	"stat.error;phot.mag;stat.fit.param", "mag"},
+  {"FLUX_MAX_SPHEROID", "Peak spheroid flux above background",
+	&outobj2.prof_spheroid_peak, H_FLOAT, T_FLOAT, "%12.7g", "count",
+	"phot.flux.sb;stat.max;stat.fit.param", "ct"},
+  {"FLUX_EFF_SPHEROID", "Effective spheroid flux above background",
+	&outobj2.prof_spheroid_fluxeff, H_FLOAT, T_FLOAT, "%12.7g", "count",
+	"phot.flux.sb;stat.fit.param", "ct"},
+  {"FLUX_MEAN_SPHEROID", "Mean effective spheroid flux above background",
+	&outobj2.prof_spheroid_fluxmean, H_FLOAT, T_FLOAT, "%12.7g", "count",
+	"phot.flux.sb;stat.mean;stat.fit.param", "ct"},
+  {"MU_MAX_SPHEROID", "Peak spheroid surface brightness above background",
+	&outobj2.prof_spheroid_mumax, H_FLOAT, T_FLOAT, "%8.4f", "mag * arcsec**(-2)",
+	"phot.mag.sb;stat.max;stat.fit.param", "mag.arcsec-2"},
+  {"MU_EFF_SPHEROID", "Effective spheroid surface brightness above background",
+	&outobj2.prof_spheroid_mueff, H_FLOAT, T_FLOAT, "%8.4f", "mag * arcsec**(-2)",
+	"phot.mag.sb;stat.fit.param", "mag.arcsec-2"},
+  {"MU_MEAN_SPHEROID", "Mean effective spheroid surface brightness above background",
+	&outobj2.prof_spheroid_mumean, H_FLOAT, T_FLOAT, "%8.4f", "mag * arcsec**(-2)",
+	"phot.mag.sb;stat.mean;stat.fit.param", "mag.arcsec-2"},
+  {"FLUXRATIO_SPHEROID", "Spheroid flux-to-total ratio from fitting",
+	&outobj2.prof_spheroid_fluxratio, H_FLOAT, T_FLOAT, "%7.5f", "",
+	"phot.count;stat.fit.param;arith.ratio", ""},
+  {"FLUXRATIOERR_SPHEROID", "RMS error on spheroid flux-to-total ratio",
+	&outobj2.prof_spheroid_fluxratioerr, H_FLOAT, T_FLOAT, "%7.5f", "",
+	"stat.error;phot.count;stat.fit.param;arith.ratio", ""},
   {"SPHEROID_REFF_IMAGE", "Spheroid effective radius from fitting",
 	&outobj2.prof_spheroid_reff, H_FLOAT, T_FLOAT, "%10.4f", "pixel",
 	"src.morph.scLength;stat.fit.param;instr.det", "pix"},
@@ -257,6 +474,30 @@
   {"MAGERR_DISK", "RMS error on fitted disk total magnitude",
 	&outobj2.prof_disk_magerr, H_FLOAT, T_FLOAT, "%8.4f", "mag",
 	"stat.error;phot.mag;stat.fit.param", "mag"},
+  {"FLUX_MAX_DISK", "Peak disk flux above background",
+	&outobj2.prof_disk_peak, H_FLOAT, T_FLOAT, "%12.7g", "count",
+	"phot.flux.sb;stat.max;stat.fit.param", "ct"},
+  {"FLUX_EFF_DISK", "Effective disk flux above background",
+	&outobj2.prof_disk_fluxeff, H_FLOAT, T_FLOAT, "%12.7g", "count",
+	"phot.flux.sb;stat.fit.param", "ct"},
+  {"FLUX_MEAN_DISK", "Mean effective disk flux above background",
+	&outobj2.prof_disk_fluxmean, H_FLOAT, T_FLOAT, "%12.7g", "count",
+	"phot.flux.sb;stat.mean;stat.fit.param", "ct"},
+  {"MU_MAX_DISK", "Peak disk surface brightness above background",
+	&outobj2.prof_disk_mumax, H_FLOAT, T_FLOAT, "%8.4f", "mag * arcsec**(-2)",
+	"phot.mag.sb;stat.max;stat.fit.param", "mag.arcsec-2"},
+  {"MU_EFF_DISK", "Effective disk surface brightness above background",
+	&outobj2.prof_disk_mueff, H_FLOAT, T_FLOAT, "%8.4f", "mag * arcsec**(-2)",
+	"phot.mag.sb;stat.fit.param", "mag.arcsec-2"},
+  {"MU_MEAN_DISK", "Mean effective disk surface brightness above background",
+	&outobj2.prof_disk_mumean, H_FLOAT, T_FLOAT, "%8.4f", "mag * arcsec**(-2)",
+	"phot.mag.sb;stat.mean;stat.fit.param", "mag.arcsec-2"},
+  {"FLUXRATIO_DISK", "Disk flux-to-total ratio from fitting",
+	&outobj2.prof_disk_fluxratio, H_FLOAT, T_FLOAT, "%7.5f", "",
+	"phot.count;stat.fit.param;arith.ratio", ""},
+  {"FLUXRATIOERR_DISK", "RMS error on disk flux-to-total ratio",
+	&outobj2.prof_disk_fluxratioerr, H_FLOAT, T_FLOAT, "%7.5f", "",
+	"stat.error;phot.count;stat.fit.param;arith.ratio", ""},
   {"DISK_SCALE_IMAGE", "Disk scalelength from fitting",
 	&outobj2.prof_disk_scale, H_FLOAT, T_FLOAT, "%10.4f", "pixel",
 	"src.morph.scLength;stat.fit.param;instr.det", "pix"},
@@ -308,6 +549,7 @@
   {"DISK_THETA_B1950", "Disk position angle (east of north, B1950)",
 	&outobj2.prof_disk_theta1950, H_FLOAT, T_FLOAT, "%+7.3f", "deg",
 	"pos.posAng;src.morph;stat.fit.param", "deg"},
+/*
   {"DISK_PATTERN_VECTOR", "Disk pattern fitted coefficients",
 	&outobj2.prof_disk_patternvector, H_FLOAT, T_FLOAT, "%12.4g", "",
 	"stat.fit.param;src.morph.param", "", 1,
@@ -323,7 +565,7 @@
   {"DISK_PATTERN_SPIRAL", "Disk pattern spiral index",
 	&outobj2.prof_disk_patternspiral, H_FLOAT, T_FLOAT, "%12.4g", "",
 	"stat.fit.param;src.morph.param", ""},
-/*
+
   {"FLUX_BAR", "Bar total flux from fitting",
 	&outobj2.prof_bar_flux, H_FLOAT, T_FLOAT, "%12.g", "count",
 	"phot.count;stat.fit.param", "ct"},
@@ -336,6 +578,12 @@
   {"MAGERR_BAR", "RMS error on fitted total bar magnitude",
 	&outobj2.prof_bar_magerr, H_FLOAT, T_FLOAT, "%8.4f", "mag",
 	"stat.error;phot.mag;stat.fit.param", "mag"},
+  {"FLUXRATIO_BAR", "Bar flux-to-total ratio from fitting",
+	&outobj2.prof_bar_fluxratio, H_FLOAT, T_FLOAT, "%7.5f", "",
+	"phot.count;stat.fit.param;arith.ratio", ""},
+  {"FLUXRATIOERR_BAR", "RMS error on bar flux-to-total ratio",
+	&outobj2.prof_bar_fluxratioerr, H_FLOAT, T_FLOAT, "%7.5f", "",
+	"stat.error;phot.count;stat.fit.param;arith.ratio", ""},
   {"BAR_LENGTH_IMAGE", "Bar length from fitting",
 	&outobj2.prof_bar_length, H_FLOAT, T_FLOAT, "%10.4f", "pixel",
 	"src.morph.scLength;stat.fit.param;instr.det", "pix"},
@@ -399,6 +647,12 @@
   {"MAGERR_ARMS", "RMS error on fitted total magnitude in spiral arms",
 	&outobj2.prof_arms_magerr, H_FLOAT, T_FLOAT, "%8.4f", "mag",
 	"stat.error;phot.mag;stat.fit.param", "mag"},
+  {"FLUXRATIO_ARMS", "Arms flux-to-total ratio from fitting",
+	&outobj2.prof_arms_fluxratio, H_FLOAT, T_FLOAT, "%7.5f", "",
+	"phot.count;stat.fit.param;arith.ratio", ""},
+  {"FLUXRATIOERR_ARMS", "RMS error on arms flux-to-total ratio",
+	&outobj2.prof_arms_fluxratioerr, H_FLOAT, T_FLOAT, "%7.5f", "",
+	"stat.error;phot.count;stat.fit.param;arith.ratio", ""},
   {"ARMS_SCALE_IMAGE", "Spiral arms scale length from fitting",
 	&outobj2.prof_arms_scale, H_FLOAT, T_FLOAT, "%10.4f", "pixel",
 	"src.morph.scLength;stat.fit.param;instr.det", "pix"},
@@ -455,3 +709,26 @@
 	&outobj2.prof_arms_quadfracerr, H_FLOAT, T_FLOAT, "%6.4f", "deg",
 	"stat.error;phot.count;arith.ratio;src.morph;stat.fit.param", "deg"},
 */
+  {"CHI2_DETMODEL", "Reduced Chi2 of the det. model fit to measurement image",
+	&outobj2.dprof_chi2, H_FLOAT, T_FLOAT, "%12.7g", "",
+	"stat.fit.chi2;src.morph", ""},
+  {"FLAGS_DETMODEL", "Detection model-fitting flags",
+	&outobj2.dprof_flag, H_INT, T_BYTE, "%3d", "",
+	"meta.code;stat.fit;src.morph", ""},
+  {"NITER_DETMODEL", "Number of iterations for detection model-fitting",
+	&outobj2.dprof_niter, H_INT, T_SHORT, "%3d", "",
+	"meta.number;stat.fit;src.morph", ""},
+
+  {"FLUX_DETMODEL", "Flux from detection model-fitting",
+	&outobj2.flux_dprof, H_FLOAT, T_FLOAT, "%12.7g", "count",
+	"phot.count;stat.fit.param", "ct"},
+  {"FLUXERR_DETMODEL", "RMS error on detection model-fitting flux",
+	&outobj2.fluxerr_dprof, H_FLOAT, T_FLOAT, "%12.7g", "count",
+	"stat.error;phot.count;stat.fit.param", "ct"},
+  {"MAG_DETMODEL", "Magnitude from detection model-fitting",
+	&outobj2.mag_dprof, H_FLOAT, T_FLOAT, "%8.4f", "mag",
+	"phot.mag;stat.fit.param", "mag"},
+  {"MAGERR_DETMODEL", "RMS error on detection model-fitting magnitude",
+	&outobj2.magerr_dprof, H_FLOAT, T_FLOAT, "%8.4f", "mag",
+	"stat.error;phot.mag;stat.fit.param", "mag"},
+
