@@ -1,18 +1,30 @@
- /*
- 				types.h
-
-*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+/*
+*				types.h
 *
-*	Part of:	SExtractor
+* Global type definitions.
 *
-*	Author:		E.BERTIN (IAP)
+*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 *
-*	Contents:	global type definitions.
+*	This file part of:	SExtractor
 *
-*	Last modify:	18/03/2009
+*	Copyright:		(C) 1993-2013 Emmanuel Bertin -- IAP/CNRS/UPMC
 *
-*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-*/
+*	License:		GNU General Public License
+*
+*	SExtractor is free software: you can redistribute it and/or modify
+*	it under the terms of the GNU General Public License as published by
+*	the Free Software Foundation, either version 3 of the License, or
+*	(at your option) any later version.
+*	SExtractor is distributed in the hope that it will be useful,
+*	but WITHOUT ANY WARRANTY; without even the implied warranty of
+*	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+*	GNU General Public License for more details.
+*	You should have received a copy of the GNU General Public License
+*	along with SExtractor. If not, see <http://www.gnu.org/licenses/>.
+*
+*	Last modified:		05/07/2013
+*
+*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%*/
 
 #include <stdio.h>
 
@@ -36,8 +48,8 @@
 
 /*----------------------------- weight flags --------------------------------*/
 
-#define		OBJ_WEIGHTZERO	0x0001
-#define		OBJ_DWEIGHTZERO 0x0002
+#define		OBJ_LOWWEIGHT	0x0001
+#define		OBJ_LOWDWEIGHT	0x0002
 
 /*---------------------------- preanalyse flags -----------------------------*/
 
@@ -59,10 +71,12 @@ typedef  enum {BACK_RELATIVE, BACK_ABSOLUTE}
 typedef  enum {CHECK_NONE, CHECK_IDENTICAL, CHECK_BACKGROUND,
         CHECK_BACKRMS, CHECK_MINIBACKGROUND, CHECK_MINIBACKRMS,
         CHECK_SUBTRACTED, CHECK_FILTERED, CHECK_OBJECTS, CHECK_APERTURES,
-	CHECK_SEGMENTATION, CHECK_ASSOC, CHECK_SUBOBJECTS,
-	CHECK_SUBPSFPROTOS, CHECK_PSFPROTOS,
-	CHECK_SUBPCPROTOS, CHECK_PCPROTOS, CHECK_PCOPROTOS,
-	CHECK_MAPSOM, CHECK_SUBPROFILES, CHECK_PROFILES, CHECK_PATTERNS,
+	CHECK_SEGMENTATION, CHECK_MASK, CHECK_SUBMASK, CHECK_ASSOC,
+	CHECK_SUBOBJECTS, CHECK_PSFPROTOS, CHECK_SUBPSFPROTOS,
+	CHECK_PCPROTOS, CHECK_SUBPCPROTOS, CHECK_PCOPROTOS,
+	CHECK_MAPSOM, CHECK_PROFILES, CHECK_SUBPROFILES,
+	CHECK_SPHEROIDS, CHECK_SUBSPHEROIDS, CHECK_DISKS, CHECK_SUBDISKS,
+	CHECK_PATTERNS,CHECK_OTHER,
 	MAXCHECK}
 		checkenum;
 	/* CHECK_IMAGE type */
@@ -81,6 +95,8 @@ typedef struct
   int		fdnpix;				/* nb of extracted pix */
   int		dnpix;				/* nb of pix above thresh  */
   int		npix;				/* "" in measured frame */
+  int		nzdwpix;			/* nb of zero-dweights around */
+  int		nzwpix;				/* nb of zero-weights inside */
   float		fdflux;				/* integrated ext. flux */
   float		dflux;				/* integrated det. flux */
   float		flux;				/* integrated mes. flux */
@@ -108,12 +124,13 @@ typedef struct
   float		cxx,cyy,cxy;			/* ellipse parameters */
   int		firstpix;			/* ptr to first pixel */
   int		lastpix;			/* ptr to last pixel */
-  float		bkg, dbkg, sigbkg;		/* Background stats (ADU) */
+  float		bkg, dbkg, sigbkg, dsigbkg;	/* Background stats (ADU) */
   float		thresh;				/* measur. threshold (ADU) */
   float		dthresh;		       	/* detect. threshold (ADU) */
   float		mthresh;		       	/* max. threshold (ADU) */
   int		iso[NISO];			/* isophotal areas */
   float		fwhm;				/* IMAGE FWHM */
+  
   }	objstruct;
 
 /* II: "BLIND" parameters */
@@ -148,11 +165,14 @@ typedef struct
   float		*magerr_aper;			/* APER mag error vector */
   float		flux_win;			/* WINdowed flux*/
   float		fluxerr_win;			/* WINdowed flux error */
+  float		snr_win;			/* WINdowed SNR */
   float		mag_win;			/* WINdowed magnitude */
   float		magerr_win;			/* WINdowed magnitude error */
 /* ---- astrometric data */
+  BYTE		area_flagw;			/* World area or SB flag */
   double	posx,posy;			/* "FITS" pos. in pixels */
   double	jacob[NAXIS*NAXIS];		/* Local deproject. Jacobian */
+  double	pixscale2;			/* Local pixel area */
   double	mamaposx,mamaposy;		/* "MAMA" pos. in pixels */
   float		sposx,sposy;			/* single precision pos. */
   float		poserr_a, poserr_b,
@@ -169,7 +189,9 @@ typedef struct
   float		poserr_cxxw, poserr_cyyw,
 		poserr_cxyw;			/* WORLD error ellipse */
   double	mx2w,my2w,mxyw;			/* WORLD var. and covar. */
+  double	peakxf, peakyf;			/* FOCAL of brightest pix */
   double	peakxw, peakyw;			/* WORLD of brightest pix */
+  double	mxf, myf;			/* FOCAL barycenters */
   double	mxw, myw;			/* WORLD barycenters */
   double	alphas, deltas;			/* native alpha, delta */
   float		thetas;				/* native position angle E/N*/
@@ -194,7 +216,7 @@ typedef struct
   float		polarw;				/* WORLD "polarization" */
   float		sprob;				/* Stellarity index */
   float		fwhmw;				/* WORLD FWHM */
-  float		*assoc;				/* ASSOCiated data */
+  double	*assoc;				/* ASSOCiated data */
   int		assoc_number;			/* nb of ASSOCiated objects */
   float		*vignet;			/* Pixel data */
   float		*vigshift;			/* (Shifted) pixel data */
@@ -228,11 +250,12 @@ typedef struct
   float		win_aw, win_bw,
 		win_thetaw;			/* WORLD ellipse parameters */
   float		win_polarw;			/* WORLD WIN "polarization" */
-  float		win_thetas;		/* native error pos. angle */
-  float		win_theta2000;		/* J2000 error pos. angle */
-  float		win_theta1950;		/* B1950 error pos. angle */
+  float		win_thetas;			/* native error pos. angle */
+  float		win_theta2000;			/* J2000 error pos. angle */
+  float		win_theta1950;			/* B1950 error pos. angle */
   float		win_cxxw, win_cyyw,
 		win_cxyw;			/* WORLD ellipse parameters */
+  double	winpos_xf, winpos_yf;		/* FOCAL coordinates */
   double	winpos_xw, winpos_yw;		/* WORLD coordinates */
   double	winpos_alphas, winpos_deltas;	/* native alpha, delta */
   double	winpos_alpha2000, winpos_delta2000;	/* J2000 alpha, delta */
@@ -255,11 +278,14 @@ typedef struct
   float		*flux_radius;			/* f-light-radii */
   float		hl_radius;			/* Scalar half-light radius */
 /* ---- PSF-fitting */
-  float		*flux_psf;			/* Flux from PSF-fitting */
-  float		*fluxerr_psf;			/* RMS error on PSF flux */
-  float		*mag_psf;			/* Mag from PSF-fitting */
-  float		*magerr_psf;			/* RMS mag from PSF-fitting */
-  float		*x_psf, *y_psf;			/* Coords from PSF-fitting */
+  float		fwhm_psf;			/* PSF FWHM */
+  float		fwhmw_psf;			/* WORLD PSF FWHM */
+  float		flux_psf;			/* Flux from PSF-fitting */
+  float		fluxerr_psf;			/* RMS error on PSF flux */
+  float		mag_psf;			/* Mag from PSF-fitting */
+  float		magerr_psf;			/* RMS mag from PSF-fitting */
+  double	x_psf, y_psf;			/* Coords from PSF-fitting */
+  double	xf_psf, yf_psf;			/* FOCAL coordinates */
   short		niter_psf;			/* # of PSF-fitting iterat. */
   short		npsf;				/* # of fitted PSFs */
   float		chi2_psf;			/* Red. chi2 of PSF-fitting */
@@ -300,8 +326,9 @@ typedef struct
   float		mag_galfit;			/* Galaxy tot. mag from fit */
   float		magerr_galfit;			/* RMS error on galfit mag */
 /* ---- Profile-fitting */
-  float		*prof_vector;			/* Profile parameters */
-  float		*prof_errvector;		/* Profile parameter errors */
+  float		*prof_vector;			/* Model parameters */
+  float		*prof_errvector;		/* Model parameter errors */
+  float		*prof_errmatrix;		/* Model parameter covariances*/
   float		prof_chi2;			/* Reduced chi2 */
   BYTE		prof_flag;			/* Model-fitting flags */
   BYTE		prof_flagw;			/* Model-fitting WORLD flag */
@@ -310,7 +337,18 @@ typedef struct
   float		fluxerr_prof;			/* RMS error on model flux */
   float		mag_prof;			/* Mag from model-fitting */
   float		magerr_prof;			/* RMS mag from model-fitting */
-  float		x_prof, y_prof;			/* Coords from model-fitting*/
+  float		peak_prof;			/* Model peak flux */
+  float		fluxeff_prof;			/* Effective model flux */
+  float		fluxmean_prof;			/* Mean effective model flux */
+  float		mumax_prof;			/* Model peak surf. bri. */
+  float		mueff_prof;			/* Model effective surf. bri. */
+  float		mumean_prof;			/* Mean model effective SB */
+  float		fluxcor_prof;			/* Hybrid model-fitting flux */
+  float		fluxcorerr_prof;		/* RMS error on hybrid flux */
+  float		magcor_prof;			/* Hybrid model-fitting mag */
+  float		magcorerr_prof;			/* RMS error on hybrid mag */
+  double	x_prof, y_prof;			/* Coords from model-fitting*/
+  double	xf_prof, yf_prof;		/* FOCAL coordinates */
   double	xw_prof, yw_prof;		/* WORLD coords */
   double	alphas_prof, deltas_prof;	/* native alpha, delta */
   double	alpha2000_prof, delta2000_prof;	/* J2000 alpha, delta */
@@ -330,18 +368,63 @@ typedef struct
   float		poserrtheta1950_prof;		/* B1950 error pos. angle */
   float		poserrcxxw_prof, poserrcyyw_prof,
 		poserrcxyw_prof;		/* WORLD error ellipse */
-  double	prof_mx2, prof_my2, prof_mxy;	/* Profile model moments */
-  double	prof_mx2w, prof_my2w, prof_mxyw;/* WORLD profile model moments*/
-  float		prof_eps1, prof_eps2;		/* Profile model ellip.vector */
-  float		prof_e1, prof_e2;		/* Profile model ellip.vector */
-  float		prof_class_star;		/* Model-fitting star/gal class*/
+  double	prof_mx2, prof_my2, prof_mxy;	/* Model-fitting moments */
+  double	prof_mx2cov[9];			/* Mod-fit moment cov. matrix */
+  float		prof_a, prof_b,
+		prof_theta;			/* Model-fitting ellip. params*/
+  float		prof_cxx, prof_cyy,
+		prof_cxy;			/* Model-fitting ellip. params*/
+  double	prof_convmx2, prof_convmy2,
+		prof_convmxy;			/* Convolved model moments */
+  float		prof_convcxx, prof_convcyy,
+		prof_convcxy;			/* Conv. model ellipse params */
+  float		prof_conva, prof_convb,
+		prof_convtheta;			/* Conv. model ellipse params */
+  float		prof_pol1, prof_pol2;		/* Model-fitting pol. vector*/
+  float		prof_pol1err, prof_pol2err,
+		prof_pol12corr;			/* Model-fitting pol. errors */
+  float		prof_e1, prof_e2;		/* Model-fitting ellip.vector*/
+  float		prof_e1err, prof_e2err,
+		prof_e12corr;			/* Model-fitting ellip. errors */
+  double	prof_mx2w, prof_my2w,
+		prof_mxyw;			/* WORLD model-fitting moments*/
+  float		prof_aw, prof_bw,
+		prof_thetaw;			/* WORLD ellipse parameters */
+  float		prof_thetas;			/* native error pos. angle */
+  float		prof_theta2000;			/* J2000 error pos. angle */
+  float		prof_theta1950;			/* B1950 error pos. angle */
+  float		prof_cxxw, prof_cyyw,
+		prof_cxyw;			/* WORLD ellipse parameters */
+  float		prof_pol1w, prof_pol2w;		/* WORLD polarisation vector*/
+  float		prof_pol1errw, prof_pol2errw,
+		prof_pol12corrw;		/* WORLD polarisation errors */
+  float		prof_e1w, prof_e2w;		/* WORLD ellipticity vector*/
+  float		prof_e1errw, prof_e2errw,
+		prof_e12corrw;			/* WORLD ellipticity errors */
+  float		prof_class_star;		/* Mod.-fitting star/gal class*/
   float		prof_concentration;		/* Model-fitting concentration*/
+  float		prof_concentrationerr;		/* RMS error */
+  float		prof_noisearea;			/* Equivalent noise area */
   float		prof_offset_flux;		/* Background offset */
   float		prof_offset_fluxerr;		/* RMS error */
+  float		prof_dirac_flux;		/* Point source total flux */
+  float		prof_dirac_fluxerr;		/* RMS error */
+  float		prof_dirac_fluxratio;		/* Point source flux ratio */
+  float		prof_dirac_fluxratioerr;	/* RMS error */
+  float		prof_dirac_mag;			/* Point source "total" mag */
+  float		prof_dirac_magerr;		/* RMS error */
   float		prof_spheroid_flux;		/* Spheroid total flux */
   float		prof_spheroid_fluxerr;		/* RMS error */
+  float		prof_spheroid_peak;		/* Spheroid peak flux */
+  float		prof_spheroid_fluxeff;		/* Spheroid effective flux */
+  float		prof_spheroid_fluxmean;		/* Spheroid mean effect. flux */
   float		prof_spheroid_mag;		/* Spheroid "total" mag */
   float		prof_spheroid_magerr;		/* RMS error */
+  float		prof_spheroid_mumax;		/* Spehroid peak surf. brigh.*/
+  float		prof_spheroid_mueff;		/* Spheroid effect. surf. bri.*/
+  float		prof_spheroid_mumean;		/* Spheroid mean eff. su. bri.*/
+  float		prof_spheroid_fluxratio;	/* Spheroid flux ratio */
+  float		prof_spheroid_fluxratioerr;	/* RMS error */
   float		prof_spheroid_reff;		/* Spheroid effective radius */
   float		prof_spheroid_refferr;		/* RMS error */
   float		prof_spheroid_reffw;		/* WORLD spheroid eff. radius */
@@ -361,8 +444,16 @@ typedef struct
   float		prof_spheroid_sersicnerr;	/* RMS error */
   float		prof_disk_flux;			/* Disk total flux */
   float		prof_disk_fluxerr;		/* RMS error */
+  float		prof_disk_peak;			/* Disk peak flux */
+  float		prof_disk_fluxeff;		/* Disk effective flux */
+  float		prof_disk_fluxmean;		/* Disk mean effective flux */
   float		prof_disk_mag;			/* Disk "total" mag */
   float		prof_disk_magerr;		/* RMS error */
+  float		prof_disk_mumax;		/* Disk peak surf. brightness */
+  float		prof_disk_mueff;		/* Disk effective surf. bri. */
+  float		prof_disk_mumean;		/* Disk mean eff. surf. bri. */
+  float		prof_disk_fluxratio;		/* Disk flux ratio */
+  float		prof_disk_fluxratioerr;		/* RMS error */
   float		prof_disk_scale;		/* Disk scale length */
   float		prof_disk_scaleerr;		/* RMS error */
   float		prof_disk_scalew;		/* WORLD disk scale length */
@@ -388,6 +479,8 @@ typedef struct
   float		prof_bar_fluxerr;		/* RMS error */
   float		prof_bar_mag;			/* Bar "total" magnitude */
   float		prof_bar_magerr;		/* RMS error */
+  float		prof_bar_fluxratio;		/* Bar flux ratio */
+  float		prof_bar_fluxratioerr;		/* RMS error */
   float		prof_bar_length;		/* Bar length */
   float		prof_bar_lengtherr;		/* RMS error */
   float		prof_bar_lengthw;		/* WORLD bar length */
@@ -409,16 +502,18 @@ typedef struct
   float		prof_arms_fluxerr;		/* RMS error */
   float		prof_arms_mag;			/* Arms "total" magnitude */
   float		prof_arms_magerr;		/* RMS error */
+  float		prof_arms_fluxratio;		/* Arms flux ratio */
+  float		prof_arms_fluxratioerr;		/* RMS error */
   float		prof_arms_scale;		/* Arms scalelength */
   float		prof_arms_scaleerr;		/* RMS error */
   float		prof_arms_scalew;		/* WORLD arms scalelength */
   float		prof_arms_scaleerrw;		/* RMS error */
   float		prof_arms_posang;		/* Arms true position angle */
   float		prof_arms_posangerr;		/* RMS error */
-//  float		prof_arms_thetaw;		/* WORLD arms position angle */
-//  float		prof_arms_thetas;		/* Sky arms position angle */
-//  float		prof_arms_theta2000;		/* J2000 arms position angle */
-//  float		prof_arms_theta1950;		/* B1950 arms position angle */
+  float		prof_arms_thetaw;		/* WORLD arms position angle */
+  float		prof_arms_thetas;		/* Sky arms position angle */
+  float		prof_arms_theta2000;		/* J2000 arms position angle */
+  float		prof_arms_theta1950;		/* B1950 arms position angle */
   float		prof_arms_pitch;		/* Arms pitch angle */
   float		prof_arms_pitcherr;		/* RMS error */
   float		prof_arms_start;		/* Arms starting radius */
@@ -427,8 +522,17 @@ typedef struct
   float		prof_arms_starterrw;		/* RMS error */
   float		prof_arms_quadfrac;		/* Arms quadrature fraction */
   float		prof_arms_quadfracerr;		/* RMS error */
-/* ---- MEF */
+  float		dprof_chi2;			/* Det. model fit reduced chi2*/
+  BYTE		dprof_flag;			/* Detection model flags*/
+  short		dprof_niter;			/* # of detection model iter. */
+  float		flux_dprof;			/* Flux in detection model*/
+  float		fluxerr_dprof;			/* Error on detect model flux */
+  float		mag_dprof;			/* Mag from detection model */
+  float		magerr_dprof;			/* RMS mag from detect. model */
+/* ---- MEF ----*/
   short		ext_number;			/* FITS extension number */
+/* ---- Time ---- */
+  float		analtime;			/* Analysis time (s) */
   }	obj2struct;
 
 /*----------------------------- lists of objects ----------------------------*/
@@ -448,6 +552,8 @@ typedef struct pic
   {
   char		filename[MAXCHAR];	/* pointer to the image filename */
   char		*rfilename;		/* pointer to the reduced image name */
+  char		hfilename[MAXCHAR];	/* external header filename */
+  int		headflag;		/* external header found? */
   char		ident[MAXCHAR];		/* field identifier (read from FITS)*/
   char		rident[MAXCHAR];	/* field identifier (relative) */
   catstruct	*cat;			/* FITS structure */
